{ // Figure 3: Willingness-to-pay (WTP) to send Pressure Message
	** Figure 3a
	use if complete==1 & attention==1 using "./data/master_long.dta", clear
	
	cumul wtpsend if pressure==1 & direct==1, gen(cumula)
	cumul wtpsend if pressure==1 & direct==0, gen(cumulb)
	label var cumula "Direct"
	label var cumulb "Anonymous"

	ksmirnov wtpsend if pressure==1, by(direct)
	local pval=string(r(p),"%3.2f")
		
	twoway (line cumula wtpsend if pressure==1 & direct==1, sort(cumula) lcolor(maroon)) ///
			(line cumulb wtpsend if pressure==1 & direct==0, sort(cumulb) lcolor(navy%60) lpattern(longdash) lwidth(medthick)), ///
			graphregion(color(white)) bgcolor(white) ///
			xscale(range(-7 7)) ///
			xlabel(-7(1)7) ///
			xlabel(-7 -6 -5 -4 -3 -2 -1, add custom labcolor(red)) ///
			xlabel(1 2 3 4 5 6 7, add custom labcolor(green)) ///
			xlabel(0, add custom labcolor(black)) ///
			xtitle("WTP to send Pressure Message ($)") ytitle("CDF") ///
			legend(order(1 "Direct" 2 "Anonymous")) ///
			ylabel(,angle(horizontal) format("%02.1f")) ///
			note("Kolmogorov Smirnov test of equality of distributions {it:p}-value<0.01")
	drop cumula cumulb
	graph export "./figures/wtpsend_cdf.eps", replace
	
	
	** Figure 3b
	use if complete==1 & attention==1 using "./data/master_long.dta", clear
	
	* Store estimates in matrix to plot as bar graph
	mat wtpsend=J(4,5,.)
	mat colnames wtpsend = pressure direct mean lb ub
	reg wtpsend 0.direct if pressure==1, cl(id)
	mat wtpsend[1,1]=1
	mat wtpsend[1,2]=1
	mat wtpsend[1,3]=_b[_cons]
	mat wtpsend[1,4]=_b[_cons]-invnorm(0.975)*_se[_cons]
	mat wtpsend[1,5]=_b[_cons]+invnorm(0.975)*_se[_cons]
	qui lincom _cons+0.direct
	mat wtpsend[2,1]=1
	mat wtpsend[2,2]=0
	mat wtpsend[2,3]=r(estimate)
	mat wtpsend[2,4]=r(lb)
	mat wtpsend[2,5]=r(ub)
	reg wtpsend 0.direct if pressure==0, cl(id)
	mat wtpsend[3,1]=0
	mat wtpsend[3,2]=1
	mat wtpsend[3,3]=_b[_cons]
	mat wtpsend[3,4]=_b[_cons]-invnorm(0.975)*_se[_cons]
	mat wtpsend[3,5]=_b[_cons]+invnorm(0.975)*_se[_cons]
	qui lincom _cons+0.direct
	mat wtpsend[4,1]=0
	mat wtpsend[4,2]=0
	mat wtpsend[4,3]=r(estimate)
	mat wtpsend[4,4]=r(lb)
	mat wtpsend[4,5]=r(ub)

	* plot estimates
	clear
	svmat wtpsend, names(col)
	cap drop xax
	gen xax=pressure*-0.9 + (0.3*3) + 0.3*(1-direct)
	twoway 	///
			(bar mean xax if pressure==1 & direct==1, fcolor(maroon%90) lcolor(maroon) barwidth(0.3) mlab(mean) mlabpos(7) mlabf("%3.2f") mlabc(maroon) mlabsize(large)) ///
			(bar mean xax if pressure==1 & direct==0, fcolor(navy%30) lcolor(navy) barwidth(0.3) mlab(mean) mlabpos(1) mlabf("%3.2f") mlabc(navy) mlabsize(large)) ///
			(rcap lb ub xax if pressure==1, lcolor(black)) ///
			, ///
		graphregion(color(white)) ///
		xlabel(none) ///
		yline(0, lcolor(gray) lwidth(medthick)) ///
		xtitle("") ///
		ysize(6) xsize(3) ///
		ylabel(-0.8(0.2)-0.2, add angle(horizontal) format("%2.1f") labcolor(red) labsize(large)) ///
		ylabel(0.2 0.4 0.6 0.8 1, add custom angle(horizontal) format("%2.1f") labcolor(green) labsize(large)) ///
		ylabel(0, add custom angle(horizontal) format("%2.1f") labcolor(black) labsize(large)) ///
		yscale(range(-0.8 1.1)) ///
		xscale(range(-0.25 0.55)) ///
		ytitle("Average WTP to send Pressure Message ($)", size(large)) ///
		legend(order(1 "Direct" 2 "Anonymous") size(large) region(lcolor(white)))
	graph export "./figures/wtpsend.eps", replace
}
