{ // Figure 4: Senders' WTP and beliefs for the Pressure Message
	** Figure 4a
	use if complete==1 & attention==1 using "./data/master_long.dta", clear
	
	* Store regression coefs to local
	reg wtpsend msgeffect c.msgeffect#1.direct 1.direct if pressure==1, cl(id)
	local Aslope=string(_b[msgeffect],"%4.2f")
	local Aslopese=string(_se[msgeffect],"%4.2f")
	local Alab="Slope=`Aslope' (SE=`Aslopese')"
	lincom msgeffect+c.msgeffect#1.direct
	local Dslope=string(`r(estimate)',"%4.2f")
	local Dslopese=string(`r(se)',"%4.2f")
	local Dlab="Slope=`Dslope' (SE=`Dslopese')"
	reg msgeffect direct if pressure==1, cl(id)
	local Ate=_b[_cons]
	local Atese=_se[_cons]
	local Atestr=string(`Ate',"%4.2f")+"pp. (SE="+string(`Atese',"%4.2f")+")"
	lincom _cons+direct
	local Dte=`r(estimate)'
	local Dtese=`r(se)'
	local Dtestr=string(`Dte',"%4.2f")+"pp. (SE="+string(`Dtese',"%4.2f")+")"
	
	binscatter wtpsend msgeffect if pressure==1, linetype(lfit) nquantiles(10) by(direct) ///
		graphregion(color(white)) bgcolor(white) ///
		xscale(range(-10 60)) xlabel(-10(10)50) ///
		yscale(range(-3 3)) ylabel(-3(1)3, angle(horizontal)) ///
		yline(0, lcolor(gray)) ///
		xsize(6) /// 
		xline(`Ate', lcolor(navy%60) lpattern(dash)) ///
		xline(`Dte', lcolor(maroon) lpattern(dash)) ///
		text(2.5 `Ate' "Anonymous mean " "`Atestr' ", placement(w) color(navy) size(small) justification(right)) ///
		text(-2.5 `Dte' " Direct mean" " `Dtestr'" " (Diff. {it:p}<0.01)", placement(e) color(maroon) size(small) justification(left)) ///
		text(2.6 43.5 "`Alab'", placement(e) color(navy) size(small)) ///
		text(1.6 43.5 "`Dlab'" "(Diff. {it:p}=0.23)", placement(e) color(maroon) size(small) justification(left)) ///
		ytitle("WTP to send Pressure Message ($)") ///
		xtitle("Predicted persuasive effect of message (pp.)") ///
		legend(order(1 "Anonymous" "Message" 2 "Direct" "Message") cols(1) pos(5) ring(0)) ///
		lcolors(navy%60 maroon) mcolors(navy%60 maroon) msymbols(circle square)
	graph export "./figures/wtpsend_msgeffect_pres_bin.eps", replace
	
	
	** Figure 4b
	use if complete==1 & attention==1 using "./data/master_long.dta", clear
	
	* Combine Strongly (Dis)agree with (Dis)agree due to small counts (pre-registered)
	replace rlikecat=2 if rlikecat==1
	replace rlikecat=6 if rlikecat==7
	
	* Store denominators to local
	qui count if pressure==1 & direct==1
	local Ndir=`r(N)'
	qui count if pressure==1 & direct==0
	local Nanon=`r(N)'
	
	* Initialize matrix to store results
	mat res = J(5,9,.)
	mat colnames res = n direct directCIU directCIL anon anonCIU anonCIL FD FA

	reg wtpsend ibn.rlikecat 1.direct#ibn.rlikecat if pressure==1, cl(id) nocons
	forvalues r=2/6 {
		
		mat res[`r'-1,1]=`r'
		
		qui lincom `r'.rlikecat#1.direct + `r'.rlikecat
		mat res[`r'-1,2]=r(estimate)
		mat res[`r'-1,3]=r(ub)
		mat res[`r'-1,4]=r(lb)
		
		qui lincom `r'.rlikecat
		mat res[`r'-1,5]=r(estimate)
		mat res[`r'-1,6]=r(ub)
		mat res[`r'-1,7]=r(lb)
		
		qui count if rlikecat==`r' & direct==1 & pressure==1
		mat res[`r'-1,8]=`r(N)'*100/`Ndir'
		
		qui count if rlikecat==`r' & direct==0 & pressure==1
		mat res[`r'-1,9]=`r(N)'*100/`Nanon'
	
	}
	
	* Load estimates and plot
	clear
	svmat2 res, names(col)
	
	gen n1=n-0.15
	gen n2=n+0.15
	gen n3=n-0.2
	gen n4=n+0.2
	
	gen FAstr=string(FA,"%2.0f")+"%"
	gen FDstr=string(FD,"%2.0f")+"%"

	twoway 	(scatter direct n1, color(maroon) msymbol(S)) ///
			(scatter anon n2, color(navy%60)) ///
			(rcap directCIU directCIL n1, lstyle(ci)) ///
			(rcap anonCIU anonCIL n2, lstyle(ci)) ///
			(bar FD n3, yaxis(2) color(maroon) barwidth(0.4)) ///
			(scatter FD n3, yaxis(2) msize(0) mlabel(FDstr) mlabpos(6) mlabc(white) mlabsize(small)) ///
			(bar FA n4, yaxis(2) color(navy%60) barwidth(0.4)) ///
			(scatter FA n4, yaxis(2) msize(0) mlabel(FAstr) mlabpos(6) mlabc(white) mlabsize(small)) ///
			, ///
			xscale(range(1.8 6.4)) xsize(7) /// 
			yscale(range(-6.5 3) axis(1)) ylabel(-3(1)3, axis(1) angle(horizontal)) ///
			yline(-3, lwidth(medthick) lcolor(black) axis(1)) ///
			yline(0, lwidth(thin) lcolor(gray) lpattern(dash) axis(1)) ///
			yscale(range(0 95) axis(2)) ylabel(0(10)30, axis(2)) ///
			ytitle("WTP to send Pressure Msg. ($)", placement(n) axis(1)) ///
			ytitle("% of responses", placement(s) axis(2) justification(centered)) ///
			xlabel(2(1)6, notick) ///
			xlabel(2 `" "(Strongly)" "disagree" "' 3 `" "Somewhat" "disagree" "', add custom labcolor(red) notick) ///
			xlabel(4 `" "Neither agree" "nor disagree" "', add custom labcolor(black) notick) ///
			xlabel(5 `" "Somewhat" "agree" "' 6 `" "(Strongly)" "agree" "', add custom labcolor(green) notick) /// ///
			xtitle(" " `" Sender`=char(39)'s response to {it:"[Recipient] would like to receive my message"  } "', justification(center) placement(s)) ///
			legend(order(1 "Direct" 2 "Anonymous") ring(0) position(10) size(small) bmargin(3 0 7.5 0)) ///  
			graphregion(color(white) margin(2 2 2 2)) bgcolor(white)
	graph export "./figures/wtpsend_rlike.eps", replace
}
