{ // Figure 6: Comparison between Pressure and Info Message conditions
	** Figure 6a
	use if complete==1 & attention==1 using "./data/master_long.dta", clear
	
	* Store averages to local
	cumul wtpsend if pressure==1, gen(cumula)
	cumul wtpsend if pressure==0, gen(cumulb)
	label var cumula "Pressure"
	label var cumulb "Info"
	qui reg wtpsend pressure, cl(id)
	local meanb = string(_b[_cons],"%4.2f")
	local seb = string(_se[_cons],"%4.2f")
	local meanbg = `meanb'-0.1
	lincom _cons+pressure
	local meana = string(r(estimate),"%4.2f")
	local sea = string(r(se),"%4.2f")
	local meanag = `meana'+0.1

	ksmirnov wtpsend, by(pressure)
	local pval=string(r(p),"%3.2f")
		
	twoway (line cumula wtpsend if pressure==1, sort(cumula) lcolor(black)) ///
			(line cumulb wtpsend if pressure==0, sort(cumulb) lcolor(purple%30) lwidth(medthick) lpattern(longdash)), ///
			graphregion(color(white)) bgcolor(white) ///
			xscale(range(-7 7)) ///
			xlabel(-7(1)7) ///
			xlabel(-7 -6 -5 -4 -3 -2 -1, add custom labcolor(red)) ///
			xlabel(1 2 3 4 5 6 7, add custom labcolor(green)) ///
			xlabel(0, add custom labcolor(black)) ///
			xtitle("WTP to send message ($)") ytitle("CDF") ///
			xline(`meana', lcolor(black)) ///
			xline(`meanb', lcolor(purple%30) lwidth(medthick) lpattern(longdash)) ///
			text(0.2 `meanag' "{&larr}Mean=`meana' (SE=`sea')", place(e) color(green) box bcolor(white)) ///size(small) 
			text(0.8 `meanbg' "Mean=`meanb' (SE=`seb'){&rarr}", place(w) color(red) box bcolor(white)) ///
			legend(order(1 "Pressure" 2 "Info")) ///
			note("Kolmogorov Smirnov test of equality of distributions {it:p}-value<0.01") ///
			ylabel(, angle(horizontal) format("%2.1f"))
	drop cumula cumulb
	graph export "./figures/wtpsend_cdf_pressure_v_info.eps", replace
	
	
	** Figure 6b
	use if complete==1 & attention==1 using "./data/master_long.dta", clear
	
	* Store regression coefs to local
	reg wtpsend msgeffect c.msgeffect#1.pressure pressure, cl(id)
	local Aslope=string(_b[msgeffect],"%4.2f")
	local Aslopese=string(_se[msgeffect],"%4.2f")
	local Alab="Slope=`Aslope' (SE=`Aslopese')"
	lincom msgeffect+c.msgeffect#1.pressure
	local Dslope=string(`r(estimate)',"%4.2f")
	local Dslopese=string(`r(se)',"%4.2f")
	local Dlab="Slope=`Dslope' (SE=`Dslopese')"
	reg msgeffect pressure, cl(id)
	local Ate=_b[_cons]
	local Atese=_se[_cons]
	local Atestr=string(`Ate',"%4.2f")+"pp. (SE="+string(`Atese',"%4.2f")+")"
	lincom _cons+pressure
	local Dte=`r(estimate)'
	local Dtese=`r(se)'
	local Dtestr=string(`Dte',"%4.2f")+"pp. (SE="+string(`Dtese',"%4.2f")+")"
	
	binscatter wtpsend msgeffect, linetype(lfit) nquantiles(10) by(pressure) ///
		graphregion(color(white)) bgcolor(white) ///
		xscale(range(-10 60)) xlabel(-10(10)50) ///
		yscale(range(-3 3)) ylabel(-3(1)3, angle(horizontal)) ///
		ylabel(-3 -2 -1, add custom labcolor(red)) ///
		ylabel(1 2 3, add custom labcolor(green)) ///
		ylabel(0, add custom labcolor(black)) ///
		yline(0, lcolor(gray%40) lwidth(medthick)) ///
		xsize(6) /// 
		xline(`Ate', lcolor(purple%60) lpattern(longdash) lwidth(medthick)) ///
		xline(`Dte', lcolor(black)) ///
		text(-2.5 `Ate' " Info Msg. mean" " `Atestr'", placement(e) color(purple) justification(left)) /// 
		text(2.5 `Dte' "Pressure Msg. mean " "`Dtestr' " "(Diff. {it:p}<0.01) ", placement(w) color(black) justification(right)) ///
		text(-0.5 40 "`Alab'" "(Diff. {it:p}<0.01)", placement(e) color(purple)  justification(left)) ///
		text(1.75 42.5 "`Dlab'", placement(e) color(black) ) ///
		ytitle("WTP to send message ($)") ///
		xtitle("Predicted instrumental persuasive effect of message (pp.)") ///
		legend(order(2 "Pressure" "Message" 1 "Info" "Message") cols(1) pos(5) ring(0)) ///
		lcolors(purple%60 black) mcolors(purple%60 black) msymbols(triangle circle)
	graph export "./figures/wtpsend_msgeffect_bin.eps", replace
}
