{ // Figure 7: Preferences and beliefs for phone-banking
	** Figure 7a
	use if attention_pass==1 & nophonebank==1 using "./data/supplemental.dta", clear
	
	* Initialize matrix to store estimates
	mat llh = J(7,2,.)
	mat colnames llh = llh p
	qui count if treated==0
	local denom=`r(N)'
	forv l=-3/3 {
		mat llh[`l'+4,1]=`l'
		qui count if likelihood==`l' & treated==0
		mat llh[`l'+4,2]=`r(N)'*100/`denom'
	}
	
	* Plot figure
	clear
	svmat2 llh, names(col)	
	
	twoway 	(bar p llh if llh<=0, barwidth(0.75) color(orange)) ///
			(bar p llh if llh==0, barwidth(0.75) color(gray)) ///
			(bar p llh if llh>0 & llh<4, barwidth(0.75) color(forest_green)) ///
			, ///
			graphregion(color(white)) bgcolor(white) ///
			xlabel(-3 `" "Very" "unlikely" "' -2 "Unlikely" -1 `" "Somewhat" "unlikely" "' 0 `" "In the" "middle" "' 1 `" "Somewhat" "likely" "' 2 "Likely" 3 `" "Very" "likely" "', labsize(small)) ///
			xtitle(" " "{it:From now until the election,}" "{it:how likely are you to volunteer in a phone banking event?}") ///
			ytitle("") subtitle("% of participants (Control Group {it:N}=`denom')", pos(11)) ///
			ylabel(0(10)60, angle(horizontal)) ///
			legend(off)
	graph export "./figures/likelihood_volunteer_control.eps", replace
	
	
	** Figure 7b
	use if attention_pass==1 & nophonebank==1 using "./data/supplemental.dta", clear
	
	* Initialize matrix to store estimates
	mat don = J(21,2,.)
	mat colnames don = don p
	qui count if treated==0
	local denom=`r(N)'
	local row=1
	forv d=0(0.5)10 {
		mat don[`row',1]=`d'
		qui count if donate==`d' & treated==0
		mat don[`row',2]=`r(N)'*100/`denom'
		local ++row
	}
	
	qui reg donate if treated==0, r
	local mean=string(_b[_cons],"%2.1f")
	local se=string(_se[_cons],"%2.1f")
	
	* Plot figure
	clear
	svmat2 don, names(col)
	
	twoway 	(bar p don, barwidth(0.5) color(navy) lcolor(none)) ///
			, ///
			graphregion(color(white)) bgcolor(white) ///
			xlabel(0(1)10) ///
			xtitle(" " "{it:How much out of $10 do you want to donate to your}" "{it:party's efforts to mobilize voters, such as phone-banking drives?}") ///
			ytitle("") subtitle("% of participants (Control Group {it:N}=`denom')", pos(11)) ///
			ylabel(0(10)40, angle(horizontal) gmin gmax) ///
			xline(`mean') ///
			text(35 `mean' "mean=`mean' (s.e.=`se')", placement(e) color(navy)) ///
			legend(off)
	graph export "./figures/donate_control.eps", replace
	
	
	** Figure 7c
	use if attention_pass==1 & nophonebank==1 using "./data/supplemental.dta", clear
	
	* Initialize matrix to store estimates
	mat aff = J(5,2,.)
	mat colnames aff = aff p
	qui count if treated==0
	local denom=`r(N)'
	local row=1
	forv a=-2(1)2 {
		mat aff[`row',1]=`a'
		qui count if affective==`a' & treated==0
		mat aff[`row',2]=`r(N)'*100/`denom'
		local ++row
	}
	
	* Plot estimates
	clear
	svmat2 aff, names(col)

	twoway 	(bar p aff if aff<0, barwidth(0.75) color(orange) lcolor(none)) ///
			(bar p aff if aff==0, barwidth(0.75) color(gray) lcolor(none)) ///
			(bar p aff if aff>0, barwidth(0.75) color(forest_green) lcolor(none)) ///
			, ///
			graphregion(color(white)) bgcolor(white) ///
			xtitle(" " "{it:People like getting phone calls from phone banking volunteers}") ///
			xlabel(-2 `" "Strongly" "disagree" "' -1 `" "Somewhat" "disagree" "' 0 `" "Neither agree" "nor disagree" "' 1 `" "Somewhat" "agree" "' 2 `" "Strongly" "agree" "', notick) ///
			ytitle("") subtitle("% of participants (Control Group {it:N}=`denom')", pos(11)) ///
			ylabel(0(10)60, angle(horizontal) gmin gmax) ///
			legend(off)
	graph export "./figures/affective_control.eps", replace
	
	
	** Figure 7d
	use if attention_pass==1 & nophonebank==1 using "./data/supplemental.dta", clear
	
	cumul instrumental_effect if nophonebank==1 & treated==0, gen(cml_inst_con)
	cumul instrumental_effect if nophonebank==1 & treated==1, gen(cml_inst_trt)

	forv t=0/1 {
		qui reg instrumental_effect if nophonebank==1 & treated==`t', r
		local inst_t`t' = string(_b[_cons],"%3.1f")
		local inst_t`t'_se = string(_se[_cons],"%3.1f")
		local inst_t`t'_N = string(`e(N)',"%3.0f")
	}
	
	twoway 	(line cml_inst_con instrumental_effect if treated==0 & instrumental_effect<=80, sort(cml_inst_con) lcolor(purple%80) lwidth(medthick)) ///
			(line cml_inst_trt instrumental_effect if treated==1 & instrumental_effect<=80, sort(cml_inst_trt) lcolor(purple) lpattern(longdash) lwidth(thick)) ///
			, ///
			graphregion(color(white) margin(2 2 2 10)) bgcolor(white) ///
			xtitle("{it:Out of 100, how many additional people do you think would}" "{it:vote for [candidate] because you called them?}") ytitle("") ///
			subtitle("CDF", placement(11)) ///
			xlabel(0(10)80, labsize(small)) ylabel(0(0.1)1, angle(horizontal) format("%2.1f") labsize(small)) ///
			legend(order(2 "Treated ({it:N}=`inst_t1_N')" 1 "Control ({it:N}=`inst_t0_N')") cols(2) pos(6) nobox region(color(none))) ///
			xline(`inst_t0', lcolor(purple%50) lwidth(medthick)) ///
			xline(`inst_t1', lcolor(purple%50) lwidth(thick) lpattern(longdash)) ///
			text(1 `inst_t0' "`inst_t0' (`inst_t0_se')", size(vsmall) color(purple) placement(e)) ///
			text(1.05 `inst_t1' "`inst_t1' (`inst_t1_se')", size(vsmall) color(purple) placement(n)) ///
			note("Vertical lines show averages with robust standard errors in parentheses")
	graph export "./figures/instrumental_cdf.eps", replace
}
