{ // Figure 8: Intend-to-treat effects of receiving peer pressure on electoral participation
	use "./data/master_wide.dta", clear	
	
	* Store N in local
	qui count if registered==0 & optional==0 & receive==0
	local cN=r(N)
	qui count if registered==0 & optional==0 & receive==1
	local tN=r(N)
	
	* Store estimates in matrix
	mat bar=J(4,6,.)
	mat colnames bar = receivebar x y lb ub pval
	mat bar[1,1]=[0\1\0\1]
	mat bar[1,2]=[0.1\0.3\0.7\0.9]
	
	reg registered_post receive if registered==0 & optional==0, r
	mat bar[1,6]=r(table)[4,1] // pval
	mat bar[2,6]=r(table)[4,1]
	
	lincom _cons
	mat bar[1,3]=r(estimate)*100
	mat bar[1,4]=r(lb)*100
	mat bar[1,5]=r(ub)*100
	
	lincom _cons+receive
	mat bar[2,3]=r(estimate)*100
	mat bar[2,4]=r(lb)*100
	mat bar[2,5]=r(ub)*100
	
	reg voted receive if registered==0 & optional==0, r
	mat bar[3,6]=r(table)[4,1] // pval
	mat bar[4,6]=r(table)[4,1]
	
	lincom _cons
	mat bar[3,3]=r(estimate)*100
	mat bar[3,4]=r(lb)*100
	mat bar[3,5]=r(ub)*100
	
	lincom _cons+receive
	mat bar[4,3]=r(estimate)*100
	mat bar[4,4]=r(lb)*100
	mat bar[4,5]=r(ub)*100
	
	* Plot estimates
	clear
	svmat bar, names(col)
	tostring y, gen(barlabel) format("%2.0f") force
	tostring pval, gen(barpval) format("%4.3f") force
	replace barlabel=barlabel+"%"
	replace barpval="{it:p}="+barpval
	
	* For lables
	gen zero=0 if x!=.
	gen one=100 if x!=.
	gen xpval=0.2 if x>0 & x<0.2
	replace xpval=0.8 if x>0.6 & x<0.8	
	
	twoway 	(bar y x if receivebar==0, barwidth(0.15) lcolor(gs7) fcolor(gs15)) ///
			(bar y x if receivebar==1, barwidth(0.15) lcolor(gs3) fcolor(gs10)) ///
			(rcap lb ub x, lwidth(0.1) lcolor(black)) ///
			(scatter zero x, msym(none) mlabel(barlabel) mlabpos(12) mlabcolor(black) mlabsize(medlarge)) ///
			(scatter one xpval, msym(none) mlabel(barpval) mlabpos(6) mlabcolor(black) mlabsize(medium)), ///
			graphregion(color(white)) bgcolor(white) ///
			xscale(range(-0.075 1.075)) ///
			xline(0.5, lpattern(dash) lcolor(black) lwidth(0.1)) ///
			xlabel(0.2 "Registration rate" 0.8 "Turnout rate", noticks) ///
			yscale(range(0 100)) yticks(0(20)100) ylabel(0(20)100) ///
			xtitle("") ytitle("Percent") ///
			legend(order(1 "Control" "(N=`cN')" 2 "Treatment" "(N=`tN')"))
	graph export "./figures/regpost_pressure.eps", replace
}
