{ // Figure A.10: Effect of anonymity for Pressure and Info Messages across beliefs on the affective effect
	use if complete==1 & attention==1 using "./data/master_long.dta", clear

	* Combine Strongly (Dis)agree with (Dis)agree due to small counts (pre-registered)
	replace rlikecat=2 if rlikecat==1
	replace rlikecat=6 if rlikecat==7
	
	* Initialize matrix to store estimates to plot
	mat res=J(5,8,.)
	mat colnames res = pres pres_lb pres_ub info info_lb info_ub pres_lin info_lin

	qui reg wtpsend msgeffect 0.direct#c.msgeffect ibn.rlikecat 0.direct#ibn.rlikecat if pressure==1, cl(id) nocons
	forv r=2/6 {
		qui lincom `r'.rlikecat#0.direct
		
		mat res[`r'-1,1]=r(estimate)
		mat res[`r'-1,2]=r(lb)
		mat res[`r'-1,3]=r(ub)
	}

	qui reg wtpsend msgeffect 0.direct#c.msgeffect ibn.rlikecat 0.direct#ibn.rlikecat if pressure==0, cl(id) nocons
	forv r=2/6 {
		qui lincom `r'.rlikecat#0.direct
		
		mat res[`r'-1,4]=r(estimate)
		mat res[`r'-1,5]=r(lb)
		mat res[`r'-1,6]=r(ub)
	}

	qui reg wtpsend 0.direct msgeffect 0.direct#c.msgeffect c.rlikecat 0.direct#c.rlikecat if pressure==1, cl(id)
	forv r=2/6 {
		qui lincom _b[0.direct] + _b[0.direct#c.rlikecat]*`r'
		
		mat res[`r'-1,7]=r(estimate)
	}

	qui reg wtpsend 0.direct msgeffect 0.direct#c.msgeffect c.rlikecat 0.direct#c.rlikecat if pressure==0, cl(id)
	forv r=2/6 {
		qui lincom _b[0.direct] + _b[0.direct#c.rlikecat]*`r'
		
		mat res[`r'-1,8]=r(estimate)
	}

	clear
	svmat2 res, names(col)
	gen n1=_n+1-0.15
	gen n2=_n+1+0.15
	gen byte n=_n+1
	
	gen pres_lab = "Pressure" if n==6
	gen info_lab = "Info" if n==6

	* Figure A.10
	twoway  (bar pres n1, color(black%90) barwidth(0.3)) (bar info n2, color(purple%30) barwidth(0.3)) ///
			(rcap pres_lb pres_ub n1, lstyle(ci)) (rcap info_lb info_ub n2, lstyle(ci)), ///
			xsize(4) ysize(3) xscale(range(1.4 6.6)) yscale(range(-1.5 3)) ytick(-1(1)3) ylabel(-1(1)3, angle(horizontal)) ///
			xlabel(2(1)6, notick) ///
			xlabel(2 `" "(Strongly)" "disagree" "' 3 `" "Somewhat" "disagree" "', add custom labcolor(red) notick) ///
			xlabel(4 `" "Neither agree" "nor disagree" "', add custom labcolor(black) notick) ///
			xlabel(5 `" "Somewhat" "agree" "' 6 `" "(Strongly)" "agree" "', add custom labcolor(green) notick) ///
			xtitle(" " `" Sender`=char(39)'s response to {it:"[Recipient] would like to receive my message"} "') ///
			legend(order(1 "Pressure Message" 2 "Info Message") rows(1) nobox region(color(none))) ///
			graphregion(color(white) margin(2 2 2 2)) bgcolor(white) ///
			ytitle("") ///
			subtitle("Average effect of {bf:anonymity} on WTP ($)", pos(11)) ///
			yline(0, lcolor(gray%50) lwidth(medthick))
	graph export "./figures/wtpsend_rlike_anon_effect_CI.eps", replace
}
