{ // Figure A.12: Likelihood of calling friends vs. strangers and affective beliefs
	use if attention_pass==1 & nophonebank==1 & friend_likelihood!=9 using "./data/supplemental.dta", clear
	
	** Figure A.12a
	
	* Store averages in local
	qui sum likelihood
	local pbmean=`r(mean)'
	qui sum friend_likelihood
	local fmean=`r(mean)'
	qui reg friend_likelihood likelihood, r
	local beta=string(_b[likelihood],"%03.2f")
	local beta_se=string(_se[likelihood],"%03.2f")
	local cons=string(_b[_cons],"%03.2f")
	local cons_se=string(_se[_cons],"%03.2f")
	
	binscatter friend_likelihood likelihood, linetype(lfit) discrete ///
		graphregion(color(white)) bgcolor(white) ///
		xscale(range(-3 3)) ///
		xlabel(-3 `" "-3 Very" "unlikely" "' -2 "-2 Unlikely" -1 `" "-1 Somewhat" "unlikely" "' 0 `" "0 In the" "middle" "' 1 `" "1 Somewhat" "likely" "' 2 "2 Likely" 3 `" "3 Very" "likely" "', labsize(vsmall) gmin gmax grid notick) ///
		yscale(range(-3 3)) /// 
		ylabel(-3 `" "-3 Very" "unlikely" "' -2 "-2 Unlikely" -1 `" "-1 Somewhat" "unlikely" "' 0 `" "0 In the" "middle" "' 1 `" "1 Somewhat" "likely" "' 2 "2 Likely" 3 `" "3 Very" "likely" "', labsize(vsmall) angle(horizontal) gmin gmax grid notick) ///
		xtitle(" " "Likelihood of volunteering for phone-banking") ///
		ytitle("") ///
		subtitle("Likelihood of calling friends", placement(11)) ///		
		legend(off) ///
		lcolors(purple) mcolors(purple) msymbols(square) ///
		xsize(10) ysize(10) ///
		xline(`pbmean', lcolor(purple%60) lpattern(longdash) lwidth(medthick)) ///
		yline(`fmean', lcolor(purple%60) lpattern(longdash) lwidth(medthick)) ///
		text(1 3 "{it:y} = `beta'{it:x} + `cons'", just(right) place(w) size(small)) /// 
		text(0.8 3 "(`beta_se')        (`cons_se')", just(right) place(w) size(vsmall))
	graph export "./figures/binscatter_friend_likelihood.eps", replace
	
	** Figure A.12b
	
	* Store averages in local
	qui sum affective
	local pbmean=`r(mean)'
	qui sum friend_affective
	local fmean=`r(mean)'
	qui reg friend_affective affective, r
	local beta=string(_b[affective],"%03.2f")
	local beta_se=string(_se[affective],"%03.2f")
	local cons=string(_b[_cons],"%03.2f")
	local cons_se=string(_se[_cons],"%03.2f")
	
	binscatter friend_affective affective, linetype(lfit) discrete ///
		graphregion(color(white)) bgcolor(white) ///
		xscale(range(-2 2)) ///
		xlabel(-2 `" "-2 Strongly" "disagree" "' -1 `" "-1 Somewhat" "disagree" "' 0 `" "0 Neither agree" "nor disagree" "' 1 `" "1 Somewhat" "agree" "' 2 `" "2 Strongly" "agree" "', labsize(vsmall) gmin gmax grid notick) ///
		yscale(range(-2 2)) /// 
		ylabel(-2 `" "-2 Strongly" "disagree" "' -1 `" "-1 Somewhat" "disagree" "' 0 `" "0 Neither agree" "nor disagree" "' 1 `" "1 Somewhat" "agree" "' 2 `" "2 Strongly" "agree" "', labsize(vsmall) angle(horizontal) gmin gmax grid notick) ///
		xtitle(" " "{it:People like getting phone calls from phone banking volunteers}", size(small)) ///
		ytitle("") ///
		subtitle("{it:My friends would like getting a phone call from me}" "{it:about voting in the election for [candidate]}", placement(11) size(small) just(left)) ///		
		legend(off) ///
		lcolors(purple) mcolors(purple) msymbols(square) ///
		xsize(10) ysize(10) ///
		xline(`pbmean', lcolor(purple%60) lpattern(longdash) lwidth(medthick)) ///
		yline(`fmean', lcolor(purple%60) lpattern(longdash) lwidth(medthick)) ///
		text(-1 2 "{it:y} = `beta'{it:x} + `cons'", just(right) place(w) size(small)) /// 
		text(-1.15 2 "(`beta_se')        (`cons_se')", just(right) place(w) size(vsmall))
	graph export "./figures/binscatter_friend_affective.eps", replace
}
