{ // Figure A.6: Sender-level WTP distributions for Pressure Message
	* Figure A.6a
	use if complete==1 & attention==1 using "./data/master_long.dta", clear
	
	collapse (mean) wtpsend, by(id direct pressure)
	replace wtpsend=ceil(wtpsend) if wtpsend>0
	replace wtpsend=floor(wtpsend) if wtpsend<0
	reshape wide wtpsend, i(id pressure) j(direct)

	heatplot wtpsend0 wtpsend1 if pressure==1, ///
		colors(sfso, reverse) ///
		xbwidth(1) ybwidth(1) ///
		cuts(0.1 1 2 4 9 30) ///
		keylabels(all, f("%2.1f") subtitle("Percent") region(lstyle(none))) ///
		graphregion(color(white)) ///
		xlabel(-7(1)7, nogrid) ///
		ylabel(-7(1)7, nogrid angle(horizontal)) ///
		xsize(6) ysize(5) ///
		xtitle("WTP to send {bf:Direct} Message ($)") ///
		ytitle("WTP to send {bf:Anonymous} Message ($)") ///
		xline(0, lwidth(medthick) lcolor(gray%30)) ///
		yline(0, lwidth(medthick) lcolor(gray%30))
	graph export "./figures/wtp_joint.eps", replace
	
	* Figure A.6b
	use if complete==1 & attention==1 using "./data/master_long.dta", clear

	collapse (mean) wtpsend (sd) wtpsend_sd=wtpsend, by(id direct pressure)
	reshape wide wtpsend wtpsend_sd, i(id) j(direct)

	gen wtpsenddiff=wtpsend1-wtpsend0 // within sender wtp send direct - anon mean

	qui count if pressure==1
	local denom=`r(N)'
	qui count if pressure==1 & wtpsenddiff>0
	local numer=`r(N)'
	local frac_pos=string(`numer'*100/`denom',"%4.2f")
	qui count if pressure==1 & wtpsenddiff<0
	local numer=`r(N)'
	local frac_neg=string(`numer'*100/`denom',"%4.2f")

	twoway 	(histogram wtpsenddiff if pressure==1, fcolor(red%30) lcolor(red) frac discrete width(0.5)) ///
			(pci 0.1 0.5 0.12 0.5, lcolor(black) lwidth(thin)) (pci 0.12 0.5 0.12 14, lcolor(black) lwidth(thin)) (pci 0.12 14 0.1 14, lcolor(black) lwidth(thin)) ///
			(pci 0.1 -0.5 0.12 -0.5, lcolor(black) lwidth(thin)) (pci 0.12 -0.5 0.12 -14, lcolor(black) lwidth(thin)) (pci 0.12 -14 0.1 -14, lcolor(black) lwidth(thin)) ///
			, ///
			graphregion(color(white)) bgcolor(white) ///
			xtitle("Within-sender Direct - Anonymous WTP difference ($)") ///
			xlabel(-14(1)14, labsize(vsmall)) ylabel(0(0.1)0.6, angle(horizontal) format("%02.1f")) ///
			legend(off) ytitle("Fraction") ///
			text(0.125 7.25 "`frac_pos'%", placement(n) color(black) size(small)) ///
			text(0.125 -7.25 "`frac_neg'%", placement(n) color(black) size(small))
	graph export "./figures/withinsender_pres.eps", replace
}
