{ // Figure A.9: WTP to send Pressure Message and beliefs on the affective effect: Heterogeneity by Sender and Recipient gender
	use if complete==1 & attention==1 using "./data/master_long.dta", clear

	* Combine Strongly (Dis)agree with (Dis)agree due to small counts (pre-registered)
	replace rlikecat=2 if rlikecat==1
	replace rlikecat=6 if rlikecat==7
	
	* Initialize matrices to store estimates 
	mat res=J(5,8,.)
	mat colnames res = m2m m2m_lin m2f m2f_lin f2m f2m_lin f2f f2f_lin  
	
	mat dir=J(5,8,.)
	mat colnames dir = m2m m2m_lin m2f m2f_lin f2m f2m_lin f2f f2f_lin  
	
	mat anon=J(5,8,.)
	mat colnames anon = m2m m2m_lin m2f m2f_lin f2m f2m_lin f2f f2f_lin  
	
	* Loop through combinations of Sender and Recipient genders
	local col=1
	forv g=0/1 {
		forv rg=0/1 {
			qui reg wtpsend msgeffect 0.direct#c.msgeffect ibn.rlikecat 0.direct#ibn.rlikecat if pressure==1 & genderbin==`g' & rgenderbin==`rg', cl(id) nocons
			
			* hold message effect fixed at mean
			qui sum msgeffect if pressure==1 & genderbin==`g' & rgenderbin==`rg'
			local msgeffectmean = `r(mean)'
			
			forv r=2/6 {
				qui lincom _b[`r'.rlikecat#0.direct] + _b[0.direct#c.msgeffect]*`msgeffectmean'
				mat res[`r'-1,`col']=r(estimate)
				
				qui lincom _b[`r'.rlikecat] + _b[msgeffect]*`msgeffectmean'
				mat dir[`r'-1,`col']=r(estimate)
				
				qui lincom _b[`r'.rlikecat] + _b[`r'.rlikecat#0.direct] + _b[msgeffect]*`msgeffectmean'+ _b[0.direct#c.msgeffect]*`msgeffectmean'
				mat anon[`r'-1,`col']=r(estimate)
			}
			
			local ++col
			
			qui reg wtpsend 0.direct msgeffect 0.direct#c.msgeffect c.rlikecat 0.direct#c.rlikecat if pressure==1 & genderbin==`g' & rgenderbin==`rg', cl(id)
			
			forv r=2/6 {
				qui lincom _b[0.direct] + _b[0.direct#c.rlikecat]*`r' + _b[0.direct#c.msgeffect]*`msgeffectmean'
				mat res[`r'-1,`col']=r(estimate)
				
				qui lincom _b[_cons] + _b[c.rlikecat]*`r' + _b[msgeffect]*`msgeffectmean'
				mat dir[`r'-1,`col']=r(estimate)
				
				qui lincom _b[_cons] + _b[c.rlikecat]*`r' + _b[0.direct] + _b[0.direct#c.rlikecat]*`r' + _b[msgeffect]*`msgeffectmean'+ _b[0.direct#c.msgeffect]*`msgeffectmean'
				mat anon[`r'-1,`col']=r(estimate)
			}
			
			local ++col
		}
	}
	
	* Figure A.9a
	clear
	svmat2 dir, names(col)
	gen n1=_n+1-0.15
	gen n2=_n+1+0.15
	gen byte n=_n+1
	
	gen m2f_lab = "Male to Fem." if n==6
	gen m2m_lab = "Male to Male" if n==6
	gen f2f_lab = "Fem. to Fem." if n==6
	gen f2m_lab = "Fem. to Male" if n==6
	
	twoway  (scatter m2m_lin n, color(none) mlab(m2m_lab) mlabpos(3) mlabsize(medsmall) mlabcol(midblue%90)) ///
			(scatter m2f_lin n, color(none) mlab(m2f_lab) mlabpos(3) mlabsize(medsmall) mlabcol(midblue%90)) ///
			(scatter f2m_lin n, color(none) mlab(f2m_lab) mlabpos(3) mlabsize(medsmall) mlabcol(magenta%90)) ///
			(scatter f2f_lin n, color(none) mlab(f2f_lab) mlabpos(3) mlabsize(medsmall) mlabcol(magenta%90)) ///
			(line m2m_lin n, color(midblue%90) lwidth(medthick)) ///
			(line m2f_lin n, color(midblue%90) lpattern(longdash) lwidth(thick)) ///
			(line f2m_lin n, color(magenta%90) lwidth(medthick)) ///
			(line f2f_lin n, color(magenta%90) lpattern(longdash) lwidth(thick)) /// 
			, ///
			xsize(4) ysize(3) ///
			xscale(range(1.75 6.25)) yscale(range(-3 3)) ytick(-3(1)3) ylabel(-3(1)3, angle(horizontal)) ///
			xlabel(2(1)6, notick) ///
			xlabel(2 `" "(Strongly)" "disagree" "' 3 `" "Somewhat" "disagree" "', add custom labcolor(red) notick) ///
			xlabel(4 `" "Neither agree" "nor disagree" "', add custom labcolor(black) notick) ///
			xlabel(5 `" "Somewhat" "agree" "' 6 `" "(Strongly)" "agree" "', add custom labcolor(green) notick) ///
			xtitle(" " `"{bf:Sender`=char(39)'s response to {it:"[Recipient] would like to receive my message"}}"') ///
			legend(off) ///
			graphregion(color(white) margin(2 15 2 2)) bgcolor(white) ///
			subtitle("WTP to send {bf:Direct} Pressure Message ($)", pos(11)) ///
			ytitle("") ///
			yline(0, lcolor(gray%50) lwidth(medthick))
	graph export "./figures/wtpsend_gender_interaction_direct.eps", replace
			
	* Figure A.9b
	clear
	svmat2 anon, names(col)
	gen n1=_n+1-0.15
	gen n2=_n+1+0.15
	gen byte n=_n+1
	
	gen m2f_lab = "Male to Fem." if n==6
	gen m2m_lab = "Male to Male" if n==6
	gen f2f_lab = "Fem. to Fem." if n==6
	gen f2m_lab = "Fem. to Male" if n==6
	
	twoway  (scatter m2m_lin n, color(none) mlab(m2m_lab) mlabpos(3) mlabsize(medsmall) mlabcol(midblue%90)) ///
			(scatter m2f_lin n, color(none) mlab(m2f_lab) mlabpos(3) mlabsize(medsmall) mlabcol(midblue%90)) ///
			(scatter f2m_lin n, color(none) mlab(f2m_lab) mlabpos(4) mlabsize(medsmall) mlabcol(magenta%90)) ///
			(scatter f2f_lin n, color(none) mlab(f2f_lab) mlabpos(2) mlabsize(medsmall) mlabcol(magenta%90)) ///
			(line m2m_lin n, color(midblue%90) lwidth(medthick)) ///
			(line m2f_lin n, color(midblue%90) lpattern(longdash) lwidth(thick)) ///
			(line f2m_lin n, color(magenta%90) lwidth(medthick)) ///
			(line f2f_lin n, color(magenta%90) lpattern(longdash) lwidth(thick)) /// 
			, ///
			xsize(4) ysize(3) ///
			xscale(range(1.75 6.25)) yscale(range(-3 3)) ytick(-3(1)3) ylabel(-3(1)3, angle(horizontal)) ///
			xlabel(2(1)6, notick) ///
			xlabel(2 `" "(Strongly)" "disagree" "' 3 `" "Somewhat" "disagree" "', add custom labcolor(red) notick) ///
			xlabel(4 `" "Neither agree" "nor disagree" "', add custom labcolor(black) notick) ///
			xlabel(5 `" "Somewhat" "agree" "' 6 `" "(Strongly)" "agree" "', add custom labcolor(green) notick) ///
			xtitle(" " `"{bf:Sender`=char(39)'s response to {it:"[Recipient] would like to receive my message"}}"') ///
			legend(off) ///
			graphregion(color(white) margin(2 15 2 2)) bgcolor(white) ///
			subtitle("WTP to send {bf:Anonymous} Pressure Message ($)", pos(11)) ///
			ytitle("") ///
			yline(0, lcolor(gray%50) lwidth(medthick))
	graph export "./figures/wtpsend_gender_interaction_anon.eps", replace
		
	* Figure A.9c
	clear
	svmat2 res, names(col)
	gen n1=_n+1-0.15
	gen n2=_n+1+0.15
	gen byte n=_n+1
	
	gen m2f_lab = "Male to Fem." if n==6
	gen m2m_lab = "Male to Male" if n==6
	gen f2f_lab = "Fem. to Fem." if n==6
	gen f2m_lab = "Fem. to Male" if n==6
	
	twoway  (scatter m2m_lin n, color(none) mlab(m2m_lab) mlabpos(3) mlabsize(medsmall) mlabcol(midblue%90)) ///
			(scatter m2f_lin n, color(none) mlab(m2f_lab) mlabpos(3) mlabsize(medsmall) mlabcol(midblue%90)) ///
			(scatter f2m_lin n, color(none) mlab(f2m_lab) mlabpos(3) mlabsize(medsmall) mlabcol(magenta%90)) ///
			(scatter f2f_lin n, color(none) mlab(f2f_lab) mlabpos(3) mlabsize(medsmall) mlabcol(magenta%90)) ///
			(line m2m_lin n, color(midblue%90) lwidth(medthick)) ///
			(line m2f_lin n, color(midblue%90) lpattern(longdash) lwidth(thick)) ///
			(line f2m_lin n, color(magenta%90) lwidth(medthick)) ///
			(line f2f_lin n, color(magenta%90) lpattern(longdash) lwidth(thick)) /// 
			, ///
			xsize(4) ysize(3) ///
			xscale(range(1.75 6.25)) yscale(range(-3 3)) ytick(-3(1)3) ylabel(-3(1)3, angle(horizontal)) ///
			xlabel(2(1)6, notick) ///
			xlabel(2 `" "(Strongly)" "disagree" "' 3 `" "Somewhat" "disagree" "', add custom labcolor(red) notick) ///
			xlabel(4 `" "Neither agree" "nor disagree" "', add custom labcolor(black) notick) ///
			xlabel(5 `" "Somewhat" "agree" "' 6 `" "(Strongly)" "agree" "', add custom labcolor(green) notick) ///
			xtitle(" " `"{bf:Sender`=char(39)'s response to {it:"[Recipient] would like to receive my message"}}"') ///
			legend(off) ///
			graphregion(color(white) margin(2 15 2 2)) bgcolor(white) ///
			subtitle("Average effect of {bf:anonymity} on WTP ($)", pos(11)) ///
			ytitle("") ///
			yline(0, lcolor(gray%50) lwidth(medthick))
	graph export "./figures/wtpsend_gender_interaction_anon_effect.eps", replace
}
