{ // Table 1: Senders' WTP and beliefs across experimental conditions
	clear all
	use if complete==1 & attention==1 using "./data/master_long.dta"
	
	* Combine Strongly (Dis)agree with (Dis)agree due to small counts (pre-registered)
	replace rlikecat=2 if rlikecat==1
	replace rlikecat=6 if rlikecat==7

	replace rlikecat=rlikecat-4 // center at 0
	replace msgeffect=msgeffect/10 // show coefs in units of 10pp.
	
	* To rename in esttab to show difference between columns
	gen di=direct
	gen me=msgeffect
	gen rl=rlikecat
	gen con=1

	eststo clear
	eststo p0: reg   wtpsend 0.direct if pressure==1, cl(id)
	eststo p1: reg   wtpsend 0.direct msgeffect rlikecat 0.direct#c.rlikecat 0.direct#c.msgeffect if pressure==1, cl(id)
	eststo i0: reg   wtpsend 0.direct if pressure==0, cl(id)
	eststo i1: reg   wtpsend 0.direct msgeffect rlikecat 0.direct#c.rlikecat 0.direct#c.msgeffect if pressure==0, cl(id)
	eststo d0: reg   wtpsend 0.di 1.pressure 1.pressure#0.direct con, cl(id) nocons
	eststo d1: reg   wtpsend 0.di me rl 0.di#c.rl 0.di#c.me 1.pressure 1.pressure#0.direct 1.pressure#c.msgeffect 1.pressure#c.rlikecat 1.pressure#0.direct#c.rlikecat 1.pressure#0.direct#c.msgeffect con, cl(id) nocons

	esttab p* i* d* using "./tables/reg.tex", ///
		substitute(\_ _) ///
		label nonumber se nostar nogaps nonotes b(%4.2f) /// 
		mlabels("(1)" "(2)" "(3)" "(4)" "(1)-(3)" "(2)-(4)", lhs("Dep. Var.: WTP to send message (\textdollar)")) ///
		rename(1.pressure#0.direct 0.direct ///
				1.pressure#c.msgeffect msgeffect ///
				1.pressure#c.rlikecat rlikecat ///
				1.pressure#0.direct#c.rlikecat 0.direct#c.rlikecat ///
				1.pressure#0.direct#c.msgeffect 0.direct#c.msgeffect ///
				1.pressure _cons ///
				) ///
		keep(0.direct msgeffect rlikecat 0.direct#c.msgeffect 0.direct#c.rlikecat _cons) ///
		order(msgeffect rlikecat 0.direct 0.direct#c.msgeffect 0.direct#c.rlikecat _cons) ///
		varlabels(0.direct "Anonymous Message" ///
				msgeffect "\hspace{1em}Instrumental: Persuasive effect (10 pp.)" ///
				rlikecat "\hspace{1em}Affective: Recipient's (dis)like [-2, 2]" ///
				0.direct#c.msgeffect "\hspace{1em}Anonymous$\times\text{Instrumental belief}$" ///
				0.direct#c.rlikecat "\hspace{1em}Anonymous$\times\text{Affective belief}$" ///
				_cons "Constant" ///
				) ///
		refcat(msgeffect "\multicolumn{7}{l}{\textbf{\textit{Sender's beliefs on the effects of the message:}}} \\ %") ///
		stat(N N_clust r2, fmt(0 0 %4.2f) label("Observations (Responses)" "Senders" "$ R^2$")) ///
		prehead(\begin{table}[h] \centering \begin{adjustbox}{max width=\textwidth} \begin{threeparttable} ///
				\caption{Senders' WTP and beliefs across experimental conditions} ///
				\begin{tabular} {l c c c c c c} \toprule /// 
				& \multicolumn{2}{c}{Pressure Msg.} & \multicolumn{2}{c}{Info Msg.} \\ ///
				\cmidrule(lr){2-3} \cmidrule(lr){4-5}) ///
		postfoot(\bottomrule \end{tabular} \label{tab:reg} ///
			\begin{tablenotes} \footnotesize ///
			\item 	OLS estimates with standard errors clustered by Sender in parentheses. ///
					The dependent variable is the Sender's willingness-to-pay (WTP) ///
					to email the message. ///
					Two beliefs are elicited from the Sender. ///
					The first is the instrumental effect, ///
					or the predicted effect of the message on the Recipient's likelihood of ///
					registering to vote by the election (Pressure Message) or ///
					knowing the names of their local legislators (Info Message). ///
					The coefficient on this prediction corresponds to a ///
					10 percentage point (pp.) increase in the predicted effectiveness. ///
					The second is the affective effect, ///
					or Sender's belief on a Likert scale for how much they agree ///
					with the statement that the Recipient would like to receive their message. ///
					The coefficient on this prediction corresponds to a ///
					1-point increase on the Likert scale ranging from -2 (strongly disagree) ///
					to 2 (strongly agree). ///
			\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}) ///
		replace
}
