{ // Table 3: Beliefs on phone-banking and willingness to volunteer or donate
	clear all
	use if attention_pass==1 & nophonebank==1 using "./data/supplemental.dta"
	
	replace instrumental_effect=instrumental_effect/10 // show coefs in units of 10pp.

	eststo clear

	reg likelihood instrumental_effect affective if treated==0, r
	eststo r1

	reg likelihood instrumental_effect affective 2.party SRS PSA big5* political ibn.fips if treated==0, nocons r
	eststo r2
	estadd local controls "\checkmark"

	reg donate instrumental_effect affective if treated==0, r
	eststo r3

	reg donate instrumental_effect affective 2.party SRS PSA big5* political ibn.fips if treated==0, nocons r
	eststo r4
	estadd local controls "\checkmark"

	esttab r* using "./tables/beliefs_corr.tex", ///
		substitute(\_ _) ///
		label nonumber se nostar nogaps nonotes b(%4.2f) /// 
		mlabels("(1)" "(2)" "(3)" "(4)", lhs("")) ///	
		keep(instrumental_effect affective 2.party SRS PSA big5_extra big5_agree big5_consc big5_emostab big5_open political _cons) ///
		order(instrumental_effect affective 2.party SRS PSA big5_extra big5_agree big5_consc big5_emostab big5_open political _cons) ///
		varlabels( ///
					instrumental_effect "\hspace{1em}Instrumental: Persuasive effect (10 pp.)" ///
					affective "\hspace{1em}Affective: Recipient's (dis)like [-2, 2]" ///
					2.party "Republican" ///
					SRS "Social Responsibility Scale" ///
					PSA "Prosocial Scale" ///
					big5_extra "\hspace{1em}Extraversion" ///
					big5_agree "\hspace{1em}Agreeableness" ///
					big5_consc "\hspace{1em}Conscientiousness" ///
					big5_emostab "\hspace{1em}Emotional Stability" ///
					big5_open "\hspace{1em}Openness to Experience" ///
					political "Political engagement index" ///
					_cons "Constant" ///
				) ///
		refcat( instrumental_effect "\multicolumn{5}{l}{\textbf{\textit{Beliefs on the effects of phone-banking}}} \\ %" ///
				big5_extra "\multicolumn{5}{l}{\textit{Big 5 Personality Traits}} \\ %") ///
		stat(controls N r2, fmt(0 0 %03.2f) label("Controls" "$ N$" "$ R^2$")) ///
		prehead(\begin{table}[h] \centering \begin{adjustbox}{totalheight=0.95\textheight} \begin{threeparttable} ///
				\caption{Beliefs on phone-banking and willingness to volunteer or donate} ///
				\begin{tabular} {l c c c c} \toprule /// 
				\multicolumn{1}{r}{\textit{Dep. var.:}} & \multicolumn{2}{c}{Likelihood of} & \multicolumn{2}{c}{Willingness to} \\ ///
				& \multicolumn{2}{c}{volunteering [-3, 3]} & \multicolumn{2}{c}{donate \textdollar[0,10]} \\ ///
				\cmidrule(lr){2-3} \cmidrule(lr){4-5}) ///
		postfoot(\bottomrule \end{tabular} \label{tab:phonebeliefs} ///
			\begin{tablenotes} \footnotesize ///
			\item This table shows OLS estimates with robust standard errors in parentheses. ///
			The sample consists of control group participants in the Supplementary General Population Survey described in Section \ref{subsec:supplement_desc}. ///
			The dependent variable in Columns 1-2 is the participants' predicted likelihood of volunteering for phone-banking by the election, with responses ranging from -3 (Very unlikely) to 3 (Very likely). ///
			The dependent variable in Columns 3-4 is how much out of \textdollar10 the participants are willing to donate to their party's mobilization efforts such as phone-banking. ///
			The instrumental beliefs are the participants' predicted effect of ///
				phone-banking on voter turnout for their party in percentage points ranging from 0 to 100. ///
			The affective beliefs is the participants' prediction of how much people like or dislike ///
				being called by phone-banking volunteers on a Likert scale ranging from -2 to 2. ///
			The Social Responsibility Scale is the average of the standardized responses to questions from \citet{BerkowitzLutterman1968}, the Prosocial Scale is the same for questions from \citet{Capraraetal2005}, as is the Big 5 Personality Traits for questions from \citet{Goslingetal2003}. ///
			The political engagement index is the average of the standardized responses to (i) whether the respondent voted in the 2020 election, (ii) whether they have donated to a political campaign, candidate, or organization in the past year, and (iii) whether they have put up a political sign at their home or a political bumper sticker on their car in the past year. ///
			The controls in Columns 2 and 4 also include state fixed effects. ///
			\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}) ///
		replace
}
