{ // Table 4a and Table A.9a: Effect of information intervention on beliefs about phone-banking
	clear all
	use if attention_pass==1 & nophonebank==1 using "./data/supplemental.dta"
	
	global controls SRS PSA big5* political i.fips 2.party
	
	eststo clear
	
	eststo r1: reg instrumental_effect treated, r
	
	eststo r2: reg instrumental_effect treated ${controls}, r
	estadd local controls "\checkmark"
	
	eststo r3: reg affective treated, r
	
	eststo r4: reg affective treated ${controls}, r
	estadd local controls "\checkmark"
	
	* Table 4a
	esttab r* using "./tables/first_stage.tex", ///
		substitute(\_ _) ///
		label nonumber se nostar nogaps nonotes b(%4.2f) /// 
		mlabels(none) eqlabels(none) ///
		keep(treated) ///
		order(treated) ///
		varlabels( ///
					treated "Treatment group" ///
				) ///
		stat(controls N r2, fmt(0 0 %03.2f) label("Controls" "$ N$" "$ R^2$")) ///
		prehead(\begin{table}[htbp!] \centering \begin{adjustbox}{max width=\linewidth} \begin{threeparttable} ///
				\caption{Effect of information intervention on beliefs about phone-banking} ///
				\begin{tabular} {l c c c c} \toprule ///
				& \multicolumn{2}{c}{Instrumental beliefs} & \multicolumn{2}{c}{Affective beliefs} \\ ///
				\cmidrule(lr){2-3} \cmidrule(lr){4-5} ///
				& (1) & (2) & (3) & (4) \\) ///
		postfoot(\bottomrule \end{tabular} \label{tab:firststage} ///
			\begin{tablenotes} \footnotesize ///
			\item This table shows OLS estimates with robust standard errors in parentheses. ///
			The treatment group receives an information intervention revealing that the average effect of ///
				volunteer phone-banking on voter turnout is 2 pp. \citep{Greenetal2013}. ///
			See Table \ref{tab:phonebeliefs} for descriptions of the dependent variables ///
				(instrumental and affective beliefs). ///
			Table A.9a reports the coefficients on the control variables. ///
			\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}) ///
		replace
}
