{ // Table 4b: Causal effect of instrumental beliefs on volunteering or donating for phone-banking
	clear all
	use if attention_pass==1 & nophonebank==1 using "./data/supplemental.dta"
	
	global controls affective SRS PSA big5* political 2.party i.fips 
	
	replace instrumental_effect=instrumental_effect/10 // show coefs in units of 10pp.
	
	eststo clear
	
	eststo r1: reg likelihood treated, r
	
	eststo r2: reg likelihood treated ${controls}, r
	estadd local controls "\checkmark"
	
	eststo r3: ivreg2 likelihood (instrumental_effect = treated), r
	
	eststo r4: ivreg2 likelihood (instrumental_effect = treated) ${controls}, r
	estadd local controls "\checkmark"

	eststo r5: reg donate treated, r
	
	eststo r6: reg donate treated ${controls}, r
	estadd local controls "\checkmark"
	
	eststo r7: ivreg2 donate (instrumental_effect = treated), r
	
	eststo r8: ivreg2 donate (instrumental_effect = treated) ${controls}, r
	estadd local controls "\checkmark"
	
	* Table 4b
	esttab r* using "./tables/IV_RF.tex", ///
		substitute(\_ _) ///
		label nonumber se nostar nogaps nonotes b(%4.2f) /// 
		mlabels(none) eqlabels(none) ///
		keep(treated instrumental_effect) ///
		order(treated instrumental_effect) ///
		varlabels( ///
					treated "Treatment group" ///
					instrumental_effect "Instrumental belief (10 pp.)" ///
				) ///
		stat(controls N r2, fmt(0 0 %03.2f) label("Controls" "$ N$" "$ R^2$")) ///
		prehead(\begin{table}[htbp!] \centering \begin{adjustbox}{max width=\linewidth} \begin{threeparttable} ///
					\caption{Causal effect of instrumental beliefs on volunteering or donating for phone-banking} ///
					\begin{tabular} {l c c c c c c c c} \toprule ///
					& \multicolumn{4}{c}{Likelihood of volunteering [-3, 3]} & \multicolumn{4}{c}{Willingness to donate \textdollar[0,10]} \\ ///
					\cmidrule(lr){2-5} \cmidrule(lr){6-9} ///
					& \multicolumn{2}{c}{RF} & \multicolumn{2}{c}{IV} & \multicolumn{2}{c}{RF} & \multicolumn{2}{c}{IV} \\ ///
					\cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} ///
					& (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) \\ ///
				) ///
		postfoot(\bottomrule \end{tabular} \label{tab:rfiv} ///
			\begin{tablenotes} \footnotesize ///
			\item This table shows OLS and IV estimates with robust standard errors in parentheses. ///
				The reduced-form estimates show the effect of the information intervention ///
					on the likelihood of volunteering (Columns 1-2) and the willingness to donate (Columns 5-6) ///
					for phone-banking. ///
				The instrumental-variable estimates show the effect of the instrumental beliefs, i.e., the ///
					persuasive effect of phone-banking (Columns 3-4, 7-8). ///
					The instrument is an indicator for receiving the information intervention; ///
					the first stage is shown in Table \ref{tab:firststage}. ///
				Table A.9b reports the coefficients on the control variables. ///
			\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}) ///
		replace
}
