{ // Table A.10: Effect of receiving a Direct Pressure Message on rates of electoral participation
	clear all
	
	* Store Senders' beliefs and WTP for actual Recipients
	use if registered==1 & send==1 & pressure==1 & optional==0 & finished==1 & rid==recipientid using "./data/master_long.dta"
	
	keep recipientid msgeffect wtpsend rlikecat 
	
	* Combine Strongly (Dis)agree with (Dis)agree due to small counts (pre-registered)
	replace rlikecat=2 if rlikecat==1
	replace rlikecat=6 if rlikecat==7
	
	isid recipientid
	rename recipientid id
	
	tempfile senders
	save `senders'
	
	use "./data/master_wide.dta", clear
	
	merge 1:1 id using `senders', assert(1 3) nogen
	
	* Standardize Senders' beliefs and WTP
	egen msgeffect_std = std(msgeffect) if registered==0 & optional==0
	egen likereceiving_std = std(rlikecat) if registered==0 & optional==0
	egen wtpsend_std = std(wtpsend) if registered==0 & optional==0
	
	* Initialize Mata matrix to store estimates
	mata
		reg = J(13,7,"")
		reg[1,1]="Receiving Direct Pressure Message"
		reg[3,1]="\hspace{1em}Instrumental: Persuasive effect of message (standardized)"
		reg[5,1]="\hspace{1em}Affective: Recipient's (dis)like of message (standardized)"
		reg[7,1]="Sender's WTP to send message (standardized)"
		reg[9,1]="Constant"
		
		reg[11,1]="Treatment group only"
		reg[12,1]="$ N$"
		reg[13,1]="K-P $ F$-stat"
	end

	qui reg registered_post 1.receive if registered==0 & optional==0, r
	local b = string(_b[1.receive],"%4.2f")
	local se = string(_se[1.receive],"%4.2f")
	mata: reg[1,2]="`b'"
	mata: reg[2,2]="("+"`se'"+")"
	local b = string(_b[_cons],"%4.2f")
	local se = string(_se[_cons],"%4.2f")
	mata: reg[9,2]="`b'"
	mata: reg[10,2]="("+"`se'"+")"
	mata: reg[12,2]="`e(N)'"

	qui ivreg2 registered_post (received = receive) if registered==0 & optional==0 & complete==1, r first rf savefirst saverf
	local b = string(_b[receive],"%4.2f")
	local se = string(_se[receive],"%4.2f")
	mata: reg[1,3]="`b'"
	mata: reg[2,3]="("+"`se'"+")"
	local b = string(_b[_cons],"%4.2f")
	local se = string(_se[_cons],"%4.2f")
	mata: reg[9,3]="`b'"
	mata: reg[10,3]="("+"`se'"+")"
	local F = string(e(widstat),"%4.2f")
	mata: reg[12,3]="`e(N)'"
	mata: reg[13,3]="`F'"

	qui reg registered_post msgeffect_std likereceiving_std wtpsend_std if registered==0 & optional==0, r
	local b = string(_b[msgeffect_std],"%4.2f")
	local se = string(_se[msgeffect_std],"%4.2f")
	mata: reg[3,4]="`b'"
	mata: reg[4,4]="("+"`se'"+")"
	local b = string(_b[likereceiving_std],"%4.2f")
	local se = string(_se[likereceiving_std],"%4.2f")
	mata: reg[5,4]="`b'"
	mata: reg[6,4]="("+"`se'"+")"
	local b = string(_b[wtpsend_std],"%4.2f")
	local se = string(_se[wtpsend_std],"%4.2f")
	mata: reg[7,4]="`b'"
	mata: reg[8,4]="("+"`se'"+")"
	local b = string(_b[_cons],"%4.2f")
	local se = string(_se[_cons],"%4.2f")
	mata: reg[9,4]="`b'"
	mata: reg[10,4]="("+"`se'"+")"
	mata: reg[11,4]="$\checkmark$"
	mata: reg[12,4]="`e(N)'"

	qui reg voted 1.receive if registered==0 & optional==0, r
	local b = string(_b[1.receive],"%4.2f")
	local se = string(_se[1.receive],"%4.2f")
	mata: reg[1,5]="`b'"
	mata: reg[2,5]="("+"`se'"+")"
	local b = string(_b[_cons],"%4.2f")
	local se = string(_se[_cons],"%4.2f")
	mata: reg[9,5]="`b'"
	mata: reg[10,5]="("+"`se'"+")"
	mata: reg[12,5]="`e(N)'"

	qui ivreg2 voted (received = receive) if registered==0 & optional==0 & complete==1, r first rf savefirst saverf
	local b = string(_b[receive],"%4.2f")
	local se = string(_se[receive],"%4.2f")
	mata: reg[1,6]="`b'"
	mata: reg[2,6]="("+"`se'"+")"
	local b = string(_b[_cons],"%4.2f")
	local se = string(_se[_cons],"%4.2f")
	mata: reg[9,6]="`b'"
	mata: reg[10,6]="("+"`se'"+")"
	local F = string(e(widstat),"%4.2f")
	mata: reg[12,6]="`e(N)'"
	mata: reg[13,6]="`F'"

	qui reg voted msgeffect_std likereceiving_std wtpsend_std if registered==0 & optional==0, r
	local b = string(_b[msgeffect_std],"%4.2f")
	local se = string(_se[msgeffect_std],"%4.2f")
	mata: reg[3,7]="`b'"
	mata: reg[4,7]="("+"`se'"+")"
	local b = string(_b[likereceiving_std],"%4.2f")
	local se = string(_se[likereceiving_std],"%4.2f")
	mata: reg[5,7]="`b'"
	mata: reg[6,7]="("+"`se'"+")"
	local b = string(_b[wtpsend_std],"%4.2f")
	local se = string(_se[wtpsend_std],"%4.2f")
	mata: reg[7,7]="`b'"
	mata: reg[8,7]="("+"`se'"+")"
	local b = string(_b[_cons],"%4.2f")
	local se = string(_se[_cons],"%4.2f")
	mata: reg[9,7]="`b'"
	mata: reg[10,7]="("+"`se'"+")"
	mata: reg[11,7]="$\checkmark$"
	mata: reg[12,7]="`e(N)'"

	mmat2tex reg using "./tables/msgeffect_nonreg.tex", ///
		replace ///
		preheader(\begin{table}[h] \centering \begin{threeparttable} ///
			\caption{Effect of receiving a Direct Pressure Message on rates of electoral participation} ///
			\begin{tabular}{l c c c c c c} \toprule ///
			& \multicolumn{3}{c}{Voter registration} & \multicolumn{3}{c}{Voter turnout} \\ ///
			\cmidrule(lr){2-4} \cmidrule(lr){5-7} ///
			& ITT & TOT & & ITT & TOT & \\ ///
			& (1) & (2) & (3) & (4) & (5) & (6) \\ ///
			\hline) ///	
		insertendrow(11 "\hline" ///
					3 "\multicolumn{7}{l}{\textbf{\textit{Sender's beliefs on the effects of the message:}}} \\ %") ///
		bottom(\bottomrule \end{tabular} \label{tab:msgeffect_nonreg} ///
		\begin{tablenotes} \footnotesize ///
		\item This table compares the voter registration and turnout rates ///
			between non-registered participants in the ///
			treatment group (assigned to receive a Direct Pressure Message) ///
			and in the control group (assigned to receive no message). ///
			Columns 1 and 4 show the intend-to-treat (ITT) results, ///
			and Columns 2 and 5 the treatment-on-treated (TOT) results. ///
			Columms 4 and 6 predict the effect of the message on the treatment group ///
			using the Sender's ///
			beliefs on the instrumental and affective effects of the message ///
			on the Recipient as well as the Sender's WTP to send the message. ///
			The Sender's beliefs and WTP have been standardized. ///
			Robust standard errors are displayed in parentheses. ///
		\end{tablenotes} \end{threeparttable} \end{table})
}
