{ // Table A.11: Non-registered Recipients: Experimental outcomes
	use "./data/master_wide.dta", clear
	
	* Initialize Mata matrix to store statistics
	mata: tab=J(8,5,"")
	
	gen byte receiveconfirmbyrecipient = receivemsg=="Yes" if receivemsg!=""
	
	* Generate categories for whether Recipient confirmed message receipt and registered/voted
	gen byte cat=cond(receiveconfirmbyrecipient==1,0,cond(receiveconfirmbyrecipient==0,1,2)) if registered==0
	label define cat 0 "Received email" 1 "Did not receive email" 2 "No response", replace
	label values cat cat
	gen byte outcome=cond(registered_post==0,0,cond(registered_post==1&voted==0,1,2)) if registered==0
	label define outcome 0 "Did not register" 1 "Registered but did not vote" 2 "Registered and voted", replace
	label values outcome outcome
	
	* Store statistics in Mata matrix
	qui tab outcome cat if registered==0 & optional==0 & receive==0, matcell(x)
	local N=r(N)
	mata
		x=st_matrix("x")
		rs=rowsum(x)
		x=x,rs
		N=`N'
		rs=rs\N
		cs=colsum(x)
		x=x\cs
		yr=100*x:/rs
		yc=100*x:/cs
		x=strofreal(x)
		yr=strofreal(yr,"%2.0f")
		yc=strofreal(yc,"%2.0f")
		y=J(rows(yr),cols(yr)," \small{[")+yc+J(rows(yr),cols(yr),"\%($\downarrow$) ")+yr+J(rows(yr),cols(yr),"\%($\rightarrow$)]}")
		z=x+y
		z=J(4,1,"0 \small{[0\%($\downarrow$) 0\%($\rightarrow$)]}"),z
		tab[1..4,2..5]=z
	end
	qui tab outcome cat if registered==0 & optional==0 & receive==1, matcell(x)
	local N=r(N)
	mata
		x=st_matrix("x")
		rs=rowsum(x)
		x=x,rs
		N=`N'
		rs=rs\N
		cs=colsum(x)
		x=x\cs
		yr=100*x:/rs
		yc=100*x:/cs
		x=strofreal(x)
		yr=strofreal(yr,"%2.0f")
		yc=strofreal(yc,"%2.0f")
		y=J(rows(yr),cols(yr)," \small{[")+yc+J(rows(yr),cols(yr),"\%($\downarrow$) ")+yr+J(rows(yr),cols(yr),"\%($\rightarrow$)]}")
		z=x+y
		tab[5..8,2..5]=z
	end

	local rowname `" "\hspace{1em}Did not register" "\hspace{1em}Registered but did not vote" "\hspace{1em}Registered and voted" "Total" "'
	forvalues i=1/4 {
		local rn: word `i' of `rowname'
		mata: tab[`i',1]="`rn'"
		mata: tab[`i'+4,1]="`rn'"
	}
	
	* Output Mata matrix to LaTeX
	mmat2tex tab using "./tables/nonreg_postelec.tex", ///
		replace ///
		preheader(\begin{table}[h] ///
			\centering \begin{threeparttable} ///
			\caption{Non-registered Recipients: Experimental outcomes} ///
			\begin{tabular} {l c c c c} \toprule ///
			& \multicolumn{3}{c}{Response in Follow-up Survey} & \\ ///
			\cmidrule(lr){2-4} ///
			& Received email & Did not receive email & No response & Total \\ ///
			\hline ///
			\multicolumn{5}{l}{\textit{\textbf{Panel A. Control group}}} \\ ///
			) ///
		insertendrow(5 "\hline \multicolumn{5}{l}{\textit{\textbf{Panel B. Treatment group}}} \\") ///	
		bottom(\bottomrule \end{tabular} \label{tab:nonreg_postelec} ///
		\begin{tablenotes} \footnotesize ///
		\item Format: Count [column frequency\%($\downarrow$) row frequency\%($\rightarrow$)] ///
		\item This table tabulates non-registered participants by ///
			the post-election experimental outcome (did not register, registered but did not vote, registered and voted) ///
			and whether they indicated in the Follow-up Survey that they had received an email ///
			from another participant in the study about registering to vote. ///
			This table excludes 15 non-registered participants who received or ///
			did not receive a message endogenously depending on their ///
			or their Sender's WTP choices. ///
		\end{tablenotes} \end{threeparttable} \end{table})
}
