{ // Table A.2: Sample characteristics
	use if (registered==1 & complete==1 & attention==1) | (registered==0) using "./data/master_wide.dta", clear

	label var regby "\hspace{1em}Current reg. rate (\%)"
	label var regfinal "\hspace{1em}Final reg. rate (\%)"
	
	* Loop over variables and collect summary stats in Mata table
	local varlist 		genderbin 	age 	racebin 	undergraduate 	stem 	yearbegin 	regby 	regfinal 
	local categorical 	1 			0 		1 			1 				0 		0 			0 		0
	local fmt 4.2
	local header 		`" "Gender" " " 	"Race/ethnicity" "Degree" "'
	mata: sum=J(0,5,"")
	local n: word count `varlist'
	gen x=.
	gen N=.
	local i=1
	foreach var in `varlist' {
		local cat: word `i' of `categorical'
		if `cat'==1 {
			local head: word `i' of `header'
			capture confirm string variable `var'
					if !_rc {
							bysort `var': replace N=_N
							sencode `var', gen(`var'encoded) gsort(-N)
					}
					else {
							gen `var'encoded=`var'
							label values `var'encoded `var'
					}	
			qui sum `var'encoded
			if `r(min)'==0 {
				local lab: label `var' 0
				label define `var'encoded 1 "`lab'", replace
				forvalues k=1/`r(max)' {
					local lab: label `var' `k'
					local numb=`k'+1
					label define `var'encoded `numb' "`lab'", add
				}
				qui replace `var'encoded=`var'encoded+1
				label values `var'encoded `var'encoded
				qui sum `var'encoded
			}
			mata: sumapp=J(`r(max)'+1,5,"")
			mata: sumapp[1,1]="\textit{`head'}"
			forvalues g=`r(min)'/`r(max)' {
				local lab: label `var'encoded `g'
				mata: sumapp[`g'+1,1]="\hspace{1em}`lab'"
				qui replace x=(`var'encoded==`g')
				
				qui sum x
				local y = string(`r(mean)',"%`fmt'f")+" ["+string(`r(sd)',"%`fmt'f")+"]"
				mata: sumapp[`g'+1,2]="`y'"
				qui sum x if registered==1
				local y = string(`r(mean)',"%`fmt'f")+" ["+string(`r(sd)',"%`fmt'f")+"]"
				mata: sumapp[`g'+1,2]="`y'"
				qui sum x if registered==0
				local y = string(`r(mean)',"%`fmt'f")+" ["+string(`r(sd)',"%`fmt'f")+"]"
				mata: sumapp[`g'+1,3]="`y'"
				qui reg x 1.registered, r
				local y = string(_b[1.registered],"%`fmt'f")+" ("+string(_se[1.registered],"%`fmt'f")+")"
				mata: sumapp[`g'+1,4]="`y'"
				local y=string((2*ttail(e(df_r),abs(_b[1.registered]/_se[1.registered]))),"%3.2f")
				mata: sumapp[`g'+1,5]="`y'"
			}
		}
		else {
			local lab: variable label `var'
			mata: sumapp=J(1,5,"")
			mata: sumapp[1,1]="`lab'"
			sum `var'
			local y = string(`r(mean)',"%`fmt'f")+" ["+string(`r(sd)',"%`fmt'f")+"]"
			mata: sumapp[1,2]="`y'"
			sum `var' if registered==1
			local y = string(`r(mean)',"%`fmt'f")+" ["+string(`r(sd)',"%`fmt'f")+"]"
			mata: sumapp[1,2]="`y'"
			sum `var' if registered==0
			local y = string(`r(mean)',"%`fmt'f")+" ["+string(`r(sd)',"%`fmt'f")+"]"
			mata: sumapp[1,3]="`y'"
			reg `var' 1.registered, r
			local y = string(_b[1.registered],"%`fmt'f")+" ("+string(_se[1.registered],"%`fmt'f")+")"
			mata: sumapp[1,4]="`y'"
			local y=string((2*ttail(e(df_r),abs(_b[1.registered]/_se[1.registered]))),"%3.2f")
			mata: sumapp[1,5]="`y'"
		}
		mata: sum=sum\sumapp
		local ++i
	}
	mata: sumapp=J(1,5,"")
	qui count
	mata: sumapp[1,2]="`r(N)'"
	qui count if registered==1
	mata: sumapp[1,2]="`r(N)'"
	qui count if registered==0
	mata: sumapp[1,3]="`r(N)'"
	mata: sum=sum\sumapp
	qui drop x N genderbinencoded racebinencoded undergraduateencoded
	mata: st_local("rows",strofreal(rows(sum)))
	local predhead=`rows'-2
	
	* Output Mata table to LaTeX
	mmat2tex sum using "./tables/r_nr_compare.tex", ///
		replace ///
		preheader(\begin{table}[h] \centering \begin{threeparttable} ///
		\caption{Sample characteristics} \begin{tabular} {l c c c c} \toprule ///
		& Registered & Non-registered & Difference (SE) & Diff. \textit{p}-value \\ \hline ///
		) ///
		insertendrow(`rows' "\hline" `predhead' "\textit{Predictions} \\") ///
		bottom(\bottomrule \end{tabular} \label{tab:r_nr_compare} ///
		\begin{tablenotes} \footnotesize ///
		\item This table shows averages with standard ///
			deviations in brackets. ///
			The \say{reg. rate} predictions ///
			refer to the forecasts for the ///
			voter registration rates on the participant's ///
			campus. ///
		\end{tablenotes} \end{threeparttable} \end{table})
}
