{ // Table A.3a: Balance: Senders
	use if (registered==1 & complete==1 & attention==1) using "./data/master_wide.dta", clear

	gen byte ratleastoneacqorfriend=(recipreln1!="Strangers")+(recipreln2!="Strangers")+(recipreln3!="Strangers")>0 if recipreln1!="" & recipreln2!="" & recipreln3!=""
	label var ratleastoneacqorfriend "\hspace{1em}At least 1 recipient is acquaintance/friend"

	gen byte rrelnallstrangers=(recipreln1=="Strangers")+(recipreln2=="Strangers")+(recipreln3=="Strangers")==3 if recipreln1!="" & recipreln2!="" & recipreln3!=""
	label var rrelnallstrangers "\hspace{1em}All 3 Recipients are strangers"
	
	* Loop over variables and collect summary stats in Mata table
	label var regby "\hspace{1em}Current reg. rate (\%)"
	label var regfinal "\hspace{1em}Final reg. rate (\%)"

	local varlist 		genderbin 	age 	racebin 	undergraduate 	stem 	yearbegin 	regby 	regfinal 	rgendermix 		rracemix rrelnallstrangers
	local categorical 	1 			0 		1 			1 				0 		0 			0 		0 			0 				0		 0
	local fmt 4.2
	local header 		`" "Gender" " " "Race/ethnicity" "Degree" "'
	mata: sum=J(0,5,"")
	local n: word count `varlist'
	gen x=.
	gen N=.
	local i=1
	foreach var in `varlist' {
		local cat: word `i' of `categorical'
		if `cat'==1 {
			local head: word `i' of `header'
			capture confirm string variable `var'
					if !_rc {
							bysort `var': replace N=_N
							sencode `var' if , gen(`var'encoded) gsort(-N)
					}
					else {
							gen `var'encoded=`var'
							label values `var'encoded `var'
					}	
			qui sum `var'encoded
			if `r(min)'==0 {
				local lab: label `var' 0
				label define `var'encoded 1 "`lab'", replace
				forvalues k=1/`r(max)' {
					local lab: label `var' `k'
					local numb=`k'+1
					label define `var'encoded `numb' "`lab'", add
				}
				qui replace `var'encoded=`var'encoded+1
				label values `var'encoded `var'encoded
				qui sum `var'encoded
			}
			mata: sumapp=J(`r(max)'+1,5,"")
			mata: sumapp[1,1]="\textit{`head'}"
			forvalues g=`r(min)'/`r(max)' {
				local lab: label `var'encoded `g'
				mata: sumapp[`g'+1,1]="\hspace{1em}`lab'"
				qui replace x=(`var'encoded==`g')
				
				qui sum x if pressure==1
				local y = string(`r(mean)',"%`fmt'f")+" ["+string(`r(sd)',"%`fmt'f")+"]"
				mata: sumapp[`g'+1,2]="`y'"
				qui sum x if pressure==0
				local y = string(`r(mean)',"%`fmt'f")+" ["+string(`r(sd)',"%`fmt'f")+"]"
				mata: sumapp[`g'+1,3]="`y'"
				qui reg x 1.pressure, r
				local y = string(_b[1.pressure],"%`fmt'f")+" ("+string(_se[1.pressure],"%`fmt'f")+")"
				mata: sumapp[`g'+1,4]="`y'"
				local y=string((2*ttail(e(df_r),abs(_b[1.pressure]/_se[1.pressure]))),"%3.2f")
				mata: sumapp[`g'+1,5]="`y'"
			}
		}
		else {
			local lab: variable label `var'
			mata: sumapp=J(1,5,"")
			mata: sumapp[1,1]="`lab'"
			
			qui sum `var' if pressure==1
			local y = string(`r(mean)',"%`fmt'f")+" ["+string(`r(sd)',"%`fmt'f")+"]"
			mata: sumapp[1,2]="`y'"
			qui sum `var' if pressure==0
			local y = string(`r(mean)',"%`fmt'f")+" ["+string(`r(sd)',"%`fmt'f")+"]"
			mata: sumapp[1,3]="`y'"
			qui reg `var' 1.pressure, r
			local y = string(_b[1.pressure],"%`fmt'f")+" ("+string(_se[1.pressure],"%`fmt'f")+")"
			mata: sumapp[1,4]="`y'"
			local y=string((2*ttail(e(df_r),abs(_b[1.pressure]/_se[1.pressure]))),"%3.2f")
			mata: sumapp[1,5]="`y'"
		}
		mata: sum=sum\sumapp
		local ++i
	}
	mata: sumapp=J(1,5,"")
	qui count if pressure==1
	mata: sumapp[1,2]="`r(N)'"
	qui count if pressure==0
	mata: sumapp[1,3]="`r(N)'"
	qui reg pressure i.genderbinencoded age i.racebinencoded i.undergraduateencoded stem yearbegin regby regfinal rgendermix rracemix ratleastoneacqorfriend, r
	testparm i.genderbinencoded age i.racebinencoded i.undergraduateencoded stem yearbegin regby regfinal rgendermix rracemix ratleastoneacqorfriend
	local y = string(Ftail(r(df),r(df_r),r(F)),"%3.2f")
	mata: sumapp[1,5]="`y'"+" (joint \textit{F}-test)"
	mata: sum=sum\sumapp
	qui drop x N genderbinencoded racebinencoded undergraduateencoded
	mata: st_local("rows",strofreal(rows(sum)))
	local rr=`rows'-3
	local ss=`rows'-4
	
	* Output Mata table to LaTeX
	mmat2tex sum using "./tables/r_balance.tex", ///
		replace ///
		preheader(\begin{table}[htbp!] \centering \begin{threeparttable} ///
		\caption{Balance: Senders} \begin{tabular} {l c c c c} \toprule ///
		& Pressure Msg. & Info Msg. & Difference (SE) & Diff. \textit{p}-value \\ \hline ///
		) ///
		insertendrow(`rows' "\hline" `ss' "\textit{Predictions} \\ " `rr' "\textit{Recipients characteristics} \\") ///
		bottom(\bottomrule \end{tabular} \label{tab:r_balance} ///
		\begin{tablenotes} \footnotesize ///
		\item This table compares the average characteristics of the  ///
				registered Senders assigned to the Pressure Message condition ///
				versus the Info Message condition. ///
				Standard deviations are shown in brackets, ///
				and robust standard errors in parentheses. ///
		\end{tablenotes} \end{threeparttable} \end{table})
}
