{ // Table A.3b: Balance: Non-registered Recipients
	use "./data/master_wide.dta", clear
		
	label var wtpshare "WTP to share status (\textdollar)"
	label var regby "\hspace{1em}Current reg. rate (\%)"
	label var regfinal "\hspace{1em}Final reg. rate (\%)"
	gen shareprefstr="Prefer not to share" if sharepref==-1
	qui replace shareprefstr="Prefer to share" if sharepref==1
	qui replace shareprefstr="Indifferent" if sharepref==0
	
	* Loop over variables and collect summary stats in Mata table
	local varlist 		genderbin 	age 	racebin 	undergraduate 	stem 	yearbegin 	shareprefstr 	wtpshare 	regby 	regfinal
	local categorical 	1 			0 		1 			1 		0 		0 			1 				0 			0 		0
	local format 		4.2 		4.2 	4.2 		4.2 	4.2 	4.2 		4.2 			4.2 		4.2 	4.2
	local header 		`" "Gender" " " "Race/ethnicity" "Degree" "Field/major" " " "Preference for sharing status" "'
	mata: sum=J(0,5,"")
	local n: word count `varlist'
	gen x=.
	gen N=.
	local i=1
	foreach var in `varlist' {
		local cat: word `i' of `categorical'
		local fmt: word `i' of `format'
		if `cat'==1 {
			local head: word `i' of `header'
			capture confirm string variable `var'
					if !_rc {
							bysort `var':  replace N=_N
							sencode `var' if registered==0 & optional==0, gen(`var'encoded) gsort(-N)
					}
					else {
							gen `var'encoded=`var' if registered==0 & optional==0
							label values `var'encoded `var'
					}	
			qui sum `var'encoded
			if `r(min)'==0 {
				local lab: label `var' 0
				label define `var'encoded 1 "`lab'", replace
				forvalues k=1/`r(max)' {
					local lab: label `var' `k'
					local numb=`k'+1
					label define `var'encoded `numb' "`lab'", add
				}
				qui replace `var'encoded=`var'encoded+1
				label values `var'encoded `var'encoded
				qui sum `var'encoded
			}
			mata: sumapp=J(`r(max)'+1,5,"")
			mata: sumapp[1,1]="\textit{`head'}"
			forvalues g=`r(min)'/`r(max)' {
				local lab: label `var'encoded `g'
				mata: sumapp[`g'+1,1]="\hspace{1em}`lab'"
				qui replace x=(`var'encoded==`g') if registered==0 & optional==0
				qui sum x if registered==0 & optional==0 & receive==1
				local y = string(`r(mean)',"%`fmt'f")+" ["+string(`r(sd)',"%`fmt'f")+"]"
				mata: sumapp[`g'+1,2]="`y'"
				qui sum x if registered==0 & optional==0 & receive==0
				local y = string(`r(mean)',"%`fmt'f")+" ["+string(`r(sd)',"%`fmt'f")+"]"
				mata: sumapp[`g'+1,3]="`y'"
				qui reg x 1.receive if registered==0 & optional==0, r
				local y = string(_b[1.receive],"%`fmt'f")+" ("+string(_se[1.receive],"%`fmt'f")+")"
				mata: sumapp[`g'+1,4]="`y'"
				local y=string((2*ttail(e(df_r),abs(_b[1.receive]/_se[1.receive]))),"%3.2f")
				mata: sumapp[`g'+1,5]="`y'"
			}
		}
		else {
			local lab: variable label `var'
			mata: sumapp=J(1,5,"")
			mata: sumapp[1,1]="`lab'"
			qui sum `var' if registered==0 & optional==0 & receive==1
			local y = string(`r(mean)',"%`fmt'f")+" ["+string(`r(sd)',"%`fmt'f")+"]"
			mata: sumapp[1,2]="`y'"
			qui sum `var' if registered==0 & optional==0 & receive==0
			local y = string(`r(mean)',"%`fmt'f")+" ["+string(`r(sd)',"%`fmt'f")+"]"
			mata: sumapp[1,3]="`y'"
			qui reg `var' 1.receive if registered==0 & optional==0, r
			local y = string(_b[1.receive],"%`fmt'f")+" ("+string(_se[1.receive],"%`fmt'f")+")"
			mata: sumapp[1,4]="`y'"
			local y=string((2*ttail(e(df_r),abs(_b[1.receive]/_se[1.receive]))),"%3.2f")
			mata: sumapp[1,5]="`y'"
		}
		mata: sum=sum\sumapp
		local ++i
	}
	mata: sumapp=J(1,5,"")
	qui count if registered==0 & optional==0 & receive==1
	mata: sumapp[1,2]="`r(N)'"
	qui count if registered==0 & optional==0 & receive==0
	mata: sumapp[1,3]="`r(N)'"
	qui reg receive i.genderbinencoded age i.racebinencoded i.undergraduateencoded stem yearbegin i.shareprefstrencoded wtpshare regby regfinal if registered==0 & optional==0, r
	testparm i.genderbinencoded age i.racebinencoded i.undergraduateencoded stem yearbegin i.shareprefstrencoded wtpshare regby regfinal
	local y = string(Ftail(r(df),r(df_r),r(F)),"%3.2f")
	mata: sumapp[1,5]="`y'"+" (joint \textit{F}-test)"

	mata: sum=sum\sumapp
	qui drop x N shareprefstr genderbinencoded racebinencoded undergraduateencoded shareprefstrencoded
	mata: st_local("rows",strofreal(rows(sum)))

	local predhead=`rows'-2

	qui count if registered==0 & optional==1
	local opt=`r(N)'
	
	* Output Mata table to LaTeX
	mmat2tex sum using "./tables/nr_balance.tex", ///
		replace ///
		preheader(\begin{table}[htbp!] \centering \begin{threeparttable} ///
		\caption{Balance: Non-registered Recipients} \begin{tabular} {l c c c c} \toprule ///
		& Control (No Msg.) & Treatment (Direct Pressure Msg.) & Difference (SE) & Diff. \textit{p}-value \\ \hline ///
		) ///
		insertendrow(`rows' "\hline" `predhead' "\textit{Predictions} \\") ///
		bottom(\bottomrule \end{tabular} \label{tab:nr_balance} ///
		\begin{tablenotes} \footnotesize ///
		\item This table compares the average characteristics of the  ///
				non-registered Recipients assigned to the treatment and control groups. ///
				Standard deviations are shown in brackets, ///
				and robust standard errors in parentheses. ///
			This table exlcudes `opt' non-registered participants who received or ///
			did not receive a message endogenously depending on their or their Sender's WTP ///
			choices. ///
		\end{tablenotes} \end{threeparttable} \end{table})
	
	
}
