{ // Table A.3d: Sample attrition
	use "./data/master_wide.dta", clear

	* Initialize Mata table
	mata
		attrition=J(7,5,"")
		attrition[1,1]="Finished Initial Survey"
		attrition[2,1]="Finished Follow-up Survey"
		attrition[3,1]="Sent required email"
		attrition[4,1]="\hspace{1em}Sent required confirmation email"
		attrition[5,1]="\hspace{1em}Sent required Direct email"
		attrition[6,1]="Passed attention check"
		attrition[7,1]="Completed study (\textbf{final sample})"
	end

	* Go through stages and record attrition in each stage
	qui count if registered==0
	local N=string(`r(N)',"%3.0f")
	mata: attrition[1,2]="`N'"
	qui count if registered==0 & finished==1
	local N=string(`r(N)',"%3.0f")
	mata: attrition[2,2]="`N'"
	mata: attrition[3,2]="NA"
	mata: attrition[4,2]="NA"
	mata: attrition[5,2]="NA"
	qui count if registered==0 & finished==1 & attention==1
	local N=string(`r(N)',"%3.0f")
	mata: attrition[6,2]="`N'"
	mata: attrition[7,2]="`N'"

	forvalues p=0/1 {
		qui count if registered==1 & pressure==`p'
		local N=string(`r(N)',"%3.0f")
		mata: attrition[1,3+`p']="`N'"
		
		qui count if registered==1 & pressure==`p' & finished==1
		local N2=string(`r(N)',"%3.0f")
		local pct=string(`N2'*100/`N',"%2.0f")
		mata: attrition[2,3+`p']="`pct'\% (`N2'/`N')"
		local N=`N2'
		
		qui count if registered==1 & pressure==`p' & finished==1 & ((optional==0 & send==0 & confirmed==1) | (optional==1 & confirmed==1) | (optional==0 & send==1 & (dm==1|((recipientnum==1&wtpsend1==-7&wtpsendmax1<=-12)|(recipientnum==2&wtpsend2==-7&wtpsendmax2<=-12)|(recipientnum==3&wtpsend3==-7&wtpsendmax3<=-12)))) | (optional==1 & dm==1))
		local N2=string(`r(N)',"%3.0f")
		local pct=string(`N2'*100/`N',"%2.0f")
		mata: attrition[3,3+`p']="`pct'\% (`N2'/`N')"
		
		qui count if registered==1 & pressure==`p' & finished==1 & ((optional==0 & send==0) | (optional==1 & confirmed==1))
		local N=string(`r(N)',"%3.0f")
		qui count if registered==1 & pressure==`p' & finished==1 & ((optional==0 & send==0 & confirmed==1) | (optional==1 & confirmed==1))
		local N2=string(`r(N)',"%3.0f")
		local pct=string(`N2'*100/`N',"%2.0f")
		mata: attrition[4,3+`p']="`pct'\% (`N2'/`N')"
		
		qui count if registered==1 & pressure==`p' & finished==1 & ((optional==0 & send==1) | (optional==1 & dm==1))
		local N=string(`r(N)',"%3.0f")
		qui count if registered==1 & pressure==`p' & finished==1 & ((optional==0 & send==1 & (dm==1|((recipientnum==1&wtpsend1==-7&wtpsendmax1<=-12)|(recipientnum==2&wtpsend2==-7&wtpsendmax2<=-12)|(recipientnum==3&wtpsend3==-7&wtpsendmax3<=-12)))) | (optional==1 & dm==1))
		local N2=string(`r(N)',"%3.0f")
		
		local pct=string(`N2'*100/`N',"%2.0f")
		if `p'==0 {
			mata: attrition[5,3+`p']="`pct'\% (`N2'/`N')"
		}
		else {
			mata: attrition[5,3+`p']="`pct'\% (`N2'/`N')$^\text{A}$"
		}
		
		qui count if registered==1 & pressure==`p' & finished==1 & ((optional==0 & send==0 & confirmed==1) | (optional==1 & confirmed==1) | (optional==0 & send==1 & (dm==1|((recipientnum==1&wtpsend1==-7&wtpsendmax1<=-12)|(recipientnum==2&wtpsend2==-7&wtpsendmax2<=-12)|(recipientnum==3&wtpsend3==-7&wtpsendmax3<=-12)))) | (optional==1 & dm==1))
		local N=string(`r(N)',"%3.0f")
		qui count if registered==1 & pressure==`p' & finished==1 & ((optional==0 & send==0 & confirmed==1) | (optional==1 & confirmed==1) | (optional==0 & send==1 & (dm==1|((recipientnum==1&wtpsend1==-7&wtpsendmax1<=-12)|(recipientnum==2&wtpsend2==-7&wtpsendmax2<=-12)|(recipientnum==3&wtpsend3==-7&wtpsendmax3<=-12)))) | (optional==1 & dm==1)) & attention==1
		local N2=string(`r(N)',"%3.0f")
		local pct=string(`N2'*100/`N',"%2.0f")
		mata: attrition[6,3+`p']="`pct'\% (`N2'/`N')"
		
		qui count if registered==1 & pressure==`p' & complete==1 & attention==1
		local N=string(`r(N)',"%3.0f")
		if `p'==0 {
			mata: attrition[7,3+`p']="\textbf{`N'}"
		}
		else {
			mata: attrition[7,3+`p']="\textbf{`N'}$^\text{B}$"
		}
	}

	reg finished pressure if registered==1, r
	local pval=string(r(table)["pvalue","pressure"],"%3.2f")
	mata: attrition[2,5]="`pval'"

	gen byte sent=((optional==0 & send==0 & confirmed==1) | (optional==1 & confirmed==1) | (optional==0 & send==1 & (dm==1|((recipientnum==1&wtpsend1==-7&wtpsendmax1<=-12)|(recipientnum==2&wtpsend2==-7&wtpsendmax2<=-12)|(recipientnum==3&wtpsend3==-7&wtpsendmax3<=-12)))) | (optional==1 & dm==1))
	reg sent pressure if registered==1 & finished==1, r
	local pval=string(r(table)["pvalue","pressure"],"%3.2f")
	mata: attrition[3,5]="`pval'"

	gen byte sent_conf=((optional==0 & send==0 & confirmed==1) | (optional==1 & confirmed==1))
	reg sent_conf pressure if registered==1 & finished==1 & ((optional==0 & send==0) | (optional==1 & confirmed==1)), r
	local pval=string(r(table)["pvalue","pressure"],"%3.2f")
	mata: attrition[4,5]="`pval'"

	gen byte sent_dir=((optional==0 & send==1 & (dm==1|((recipientnum==1&wtpsend1==-7&wtpsendmax1<=-12)|(recipientnum==2&wtpsend2==-7&wtpsendmax2<=-12)|(recipientnum==3&wtpsend3==-7&wtpsendmax3<=-12)))) | (optional==1 & dm==1))
	tab sent_dir pressure if registered==1 & finished==1 & ((optional==0 & send==1) | (optional==1 & dm==1)), exact
	local pval=string(r(p_exact),"%3.2f")
	mata: attrition[5,5]="`pval'$^\text{C}$"

	reg attention pressure if registered==1 & finished==1 & sent==1, r
	local pval=string(r(table)["pvalue","pressure"],"%3.2f")
	mata: attrition[6,5]="`pval'"

	* Output Mata table to LaTeX
	mmat2tex attrition using "./tables/attrition.tex", ///
		replace ///
		preheader(\begin{table}[htbp!] ///
			\centering \begin{adjustbox}{max width=\linewidth} \begin{threeparttable} ///
			\caption{Sample attrition} ///
			\begin{tabular} {l c c c c} \toprule ///
			& Non-registered & \multicolumn{2}{c}{Registered} &  \\ ///
			\cmidrule(lr){3-4} ///
			& & (1) Info Message & (2) Pressure Message & (1)-(2) $ p\text{-val.}$ \\ ///
			\hline ///
			) ///
		insertendrow(7 "\hline") ///	
		bottom(\bottomrule \end{tabular} \label{tab:attrition} ///
		\begin{tablenotes} \footnotesize ///
		\item This table shows the frequency of participants remaining after each sample restriction. The frequency is shown for the Senders separately by the Pressure and Info Message conditions. The last column shows the $ p\text{-value}$ of the difference in the frequency at each restriction. ///
		\item $^{\text{A}}\text{As}$ pre-registered, 1 participant who finished the Follow-up survey, stated a WTP to send the Direct Message of less than {\textdollar}12, ///
				and did not send the Direct Message is considered to have fulfilled the \say{Sent required Direct Message} condition. ///
		\item $^{\text{B}} 2$ participants stated that they did not know how to fill out the WTP responses in the open-ended feedback box. ///
				Consequently, although they completed all the study requirements, their WTP responses are not included in the analysis. ///
		\item $^{\text{C}}p\text{-value}$ calculated using Fisher's exact test given the low counts in some of the 2x2 cells. ///
		\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table})
}
