{ // Table A.4: Sample characteristics: Supplementary General Population Survey sample
	use if nophonebank==1 & attention_pass==1 using "./data/supplemental.dta", clear
	
	** Initialize Mata matrix and fill in
	** Column 1 Descriptions
	mata
		tab=J(17,7,"")
		row=1
		
		tab[row,1]="Republican"
		++row
		tab[row,1]="Female/other"
		++row
	end

	foreach agegroup in "18-24" "25-34" "35-44" "45-54" "55-64" "65+" {
		mata: tab[row,1]="\hspace{1em}`agegroup'"
		mata: ++row
	}

	foreach region in "Northeast" "Midwest" "South" "West" {
		mata: tab[row,1]="\hspace{1em}`region'"
		mata: ++row
	}

	mata
		mata: tab[row,1]="\hspace{1em}Ideology rating"
		mata: ++row
		mata: tab[row,1]="\hspace{1em}Voted in 2020 election"
		mata: ++row
		mata: tab[row,1]="\hspace{1em}Political donation in 2024"
		mata: ++row
		mata: tab[row,1]="\hspace{1em}Political sign in 2024"
		mata: ++row
	end
	
	mata: tab[row,1]="$ N\text{/}p\text{-value}$"

	** Column 2 General population statistics	
	import delimited using "./data/ACS2023.csv", clear
	
	global republican 0.502 // As of 11/15/2024, 50.2% Trump popular vote
	
	mata: row=1
	local x=string(${republican},"%03.2f")
	mata: tab[row,2]="`x'"
	mata: ++row
	
	foreach var in femaleother age_1824 age_2534 age_3544 age_4554 age_5564 age_65 region_northeast region_midwest region_south region_west {
		global `var' = `var'[1]
		local x=string(`var'[1],"%03.2f")
		mata: tab[row,2]="`x'"
		mata: ++row
	}
	
	** Column 3-4 Sample statistics and differences
	use if !(nophonebank==0 | attention_pass==0) using "./data/supplemental.dta", clear
	
	gen byte republican = party==2
	gen byte femaleother = gender!=2
	
	local a=1
	foreach agegroup in 1824 2534 3544 4554 5564 65 {
		gen byte age_`agegroup' = age==`a'
		local ++a
	}
	
	local r=1
	foreach reg in northeast midwest south west {
		gen byte region_`reg' = region==`r'
		local ++r
	}
	
	global ftest
	mata: row=1
	foreach var in republican femaleother age_1824 age_2534 age_3544 age_4554 age_5564 age_65 region_northeast region_midwest region_south region_west ideo voted2020 political_donated political_sign {
		qui sum `var' if nophonebank==1
		local mean = string(`r(mean)',"%03.2f")
		local sd = string(`r(sd)',"%03.2f")
		mata: tab[row,3]="`mean' \footnotesize{[`sd']}"
		if "${`var'}"!="" {
			qui reg `var'  if nophonebank==1, r
			qui lincom ${`var'}-_cons
			local est = string(`r(estimate)',"%03.2f")
			local se = string(`r(se)',"%03.2f")
			mata: tab[row,4]="`est' \footnotesize{(`se')}"
			
			* for F-test
			qui reg `var' if nophonebank==1
			est sto `var'
			global ftest ${ftest} ([`var'_mean]_cons==${`var'})
		}
		mata: ++row
	}
	qui count if nophonebank==1
	local N=`r(N)'
	mata: tab[row,3]="`N'"
	
	qui suest republican femaleother age_1824 age_2534 age_3544 age_4554 age_5564 age_65 region_northeast region_midwest region_south region_west, r
	qui test ${ftest}
	local pval=string(`r(p)',"%03.2f")
	mata: tab[row,4]="`pval' (F-test)"
	
	** Column 5-7 Sample statistics and differences by treatment
	forv t=1(-1)0 {
		mata: row=1
		foreach var in republican femaleother age_1824 age_2534 age_3544 age_4554 age_5564 age_65 region_northeast region_midwest region_south region_west ideo voted2020 political_donated political_sign {
			qui sum `var' if nophonebank==1 & treated==`t'
			local mean = string(`r(mean)',"%03.2f")
			local sd = string(`r(sd)',"%03.2f")
			mata: tab[row,6-`t']="`mean' \footnotesize{[`sd']}"
			mata: ++row
		}
		qui count if nophonebank==1 & treated==`t'
		local N=`r(N)'
		mata: tab[row,6-`t']="`N'"
	}
	
	mata: row=1
	global ftest
	foreach var in republican femaleother age_1824 age_2534 age_3544 age_4554 age_5564 age_65 region_northeast region_midwest region_south region_west ideo voted2020 political_donated political_sign {
		qui reg `var' treated if nophonebank==1
		est sto `var'
		qui lincom treated
		
		local est = string(`r(estimate)',"%03.2f")
		local se = string(`r(se)',"%03.2f") 
		mata: tab[row,7]="`est' \footnotesize{(`se')}"
		
		global ftest ${ftest} ([`var'_mean]treated==0)
		
		mata: ++row
	}
	
	qui suest republican femaleother age_1824 age_2534 age_3544 age_4554 age_5564 age_65 region_northeast region_midwest region_south region_west ideo voted2020 political_donated political_sign, r
	qui test ${ftest}
	local pval=string(`r(p)',"%03.2f")
	mata: tab[row,7]="`pval' (F-test)"
		
	
	* Output Mata matrix to LaTeX
	mmat2tex tab using "./tables/sample2024.tex", ///
	replace ///
	preheader(\begin{table}[htbp!] ///
			\centering \begin{threeparttable} ///
			\caption{Sample characteristics: Supplementary General Population Survey sample} ///
			\begin{tabular} {l c c c c c c} \toprule ///
			& U.S. Citizen Pop. & Sample & Diff. \footnotesize{(SE)} & Treatment & Control & Diff. \footnotesize{(SE)} \\ ///
			& (1) & (2) & (1)-(2) & (3) & (4) & (3)-(4) \\ ///
			\hline ///
		) ///
	insertendrow(	///
					3 "\multicolumn{7}{l}{\textit{Age group}} \\ %" ///
					9 "\multicolumn{7}{l}{\textit{Census region}} \\ %" ///
					13 "\multicolumn{7}{l}{\textit{Prior political engagement}} \\ %" ///
					17 "\hline" ///
				) ///	
	bottom(\bottomrule \end{tabular} \label{tab:sample2024} ///
	\begin{tablenotes} \footnotesize ///
	\item ///
		This table shows the average characteristics of the Supplementary General Population Survey sample ///
			for the 2024 Election, ///
			with standard deviations shown in brackets. ///
		Column 1 shows the averages for the general population of U.S. citizens from the ///
			ACS 1-Year Estimates Public Use Microdata Sample 2023. ///
		Column 2 shows the averages for the survey sample, Column 3 for the treatment group, ///
			and Column 4 for the control group. ///
		Robust standard errors for the differences are reported in parentheses. ///
		\say{Republican} refers to the popular voteshare in Column 1, ///
			and to whether the respondent planned to vote for Donald Trump and JD Vance in the other columns. ///
		\say{Ideology rating} is the self-rated political ideology ///
		from -3 (Very liberal) to 3 (Very conservative). ///
		\say{Political donation in 2024} indicates that the respondent had made a political contribution ///
			in the year leading up to the 2024 election. ///
		\say{Political sign in 2024} means that the respondent had put up a political sign at their home ///
			or a political bumper sticker on their car. ///
	\end{tablenotes} \end{threeparttable} \end{table}) 
}
