{ // Table A.5: Senders' WTP and beliefs for the Pressure Message: Heterogeneity by gender
	clear all
	use if complete==1 & attention==1 using "./data/master_long.dta"

	* Combine Strongly (Dis)agree with (Dis)agree due to small counts (pre-registered)
	replace rlikecat=2 if rlikecat==1
	replace rlikecat=6 if rlikecat==7

	replace rlikecat=rlikecat-4 // center at 0
	replace msgeffect=msgeffect/10 // show coefs in units of 10pp.
	
	* To rename in esttab to show difference between columns
	gen di=direct
	gen me=msgeffect
	gen rl=rlikecat
	gen cons=1

	eststo clear
	
	reg wtpsend 1.rgenderbin if pressure==1 &genderbin==0 & direct==0, cl(id)
	
	eststo f1: reg wtpsend 0.direct msgeffect rlikecat 0.direct#c.rlikecat 0.direct#c.msgeffect if pressure==1 &genderbin==1 & rgenderbin==1, cl(id)
	eststo f2: reg wtpsend 0.direct msgeffect rlikecat 0.direct#c.rlikecat 0.direct#c.msgeffect if pressure==1 &genderbin==1 & rgenderbin==0, cl(id)
							
	
	eststo m1: reg wtpsend 0.direct msgeffect rlikecat 0.direct#c.rlikecat 0.direct#c.msgeffect if pressure==1 &genderbin==0 & rgenderbin==1, cl(id)
	eststo m2: reg wtpsend 0.direct msgeffect rlikecat 0.direct#c.rlikecat 0.direct#c.msgeffect if pressure==1 &genderbin==0 & rgenderbin==0, cl(id)
	
	
	eststo d1: reg wtpsend 0.di me rl 0.di#c.rl 0.di#c.me cons ///
						1.rgenderbin 1.rgenderbin#0.direct 1.rgenderbin#c.msgeffect 1.rgenderbin#c.rlikecat 1.rgenderbin#0.direct#c.rlikecat 1.rgenderbin#0.direct#c.msgeffect ///
						if pressure==1 & genderbin==1, cl(id) nocons
	eststo d2: reg wtpsend 0.di me rl 0.di#c.rl 0.di#c.me cons ///
						1.rgenderbin 1.rgenderbin#0.direct 1.rgenderbin#c.msgeffect 1.rgenderbin#c.rlikecat 1.rgenderbin#0.direct#c.rlikecat 1.rgenderbin#0.direct#c.msgeffect ///
						if pressure==1 & genderbin==0, cl(id) nocons
	eststo d3: reg wtpsend 0.di me rl 0.di#c.rl 0.di#c.me cons ///
						1.genderbin 1.genderbin#0.direct 1.genderbin#c.msgeffect 1.genderbin#c.rlikecat 1.genderbin#0.direct#c.rlikecat 1.genderbin#0.direct#c.msgeffect ///
						if pressure==1 & rgenderbin==1, cl(id) nocons
	eststo d4: reg wtpsend 0.di me rl 0.di#c.rl 0.di#c.me cons ///
						1.genderbin 1.genderbin#0.direct 1.genderbin#c.msgeffect 1.genderbin#c.rlikecat 1.genderbin#0.direct#c.rlikecat 1.genderbin#0.direct#c.msgeffect ///
						if pressure==1 & rgenderbin==0, cl(id) nocons
						
	esttab f* m* d* using "./tables/heterogeneity_gender.tex", ///
		substitute(\_ _) ///
		label nonumber se nostar nogaps nonotes b(%4.2f) /// 
		mlabels("(1)" "(2)" "(3)" "(4)" "(1)-(2)" "(3)-(4)" "(1)-(3)" "(2)-(4)", ///
				lhs("Dep. Var.: WTP to send Pressure Msg. (\textdollar)")) ///
		rename( 1.rgenderbin#0.direct 0.direct ///
				1.rgenderbin#c.msgeffect msgeffect ///
				1.rgenderbin#c.rlikecat rlikecat ///
				1.rgenderbin#0.direct#c.rlikecat 0.direct#c.rlikecat ///
				1.rgenderbin#0.direct#c.msgeffect 0.direct#c.msgeffect ///
				1.rgenderbin _cons ///
				1.genderbin#0.direct 0.direct ///
				1.genderbin#c.msgeffect msgeffect ///
				1.genderbin#c.rlikecat rlikecat ///
				1.genderbin#0.direct#c.rlikecat 0.direct#c.rlikecat ///
				1.genderbin#0.direct#c.msgeffect 0.direct#c.msgeffect ///
				1.genderbin _cons ///
				) ///
		keep(0.direct msgeffect rlikecat 0.direct#c.msgeffect 0.direct#c.rlikecat _cons) ///
		order(msgeffect rlikecat 0.direct 0.direct#c.msgeffect 0.direct#c.rlikecat _cons) ///
		varlabels(0.direct "Anonymous Message" ///
				msgeffect "\hspace{1em}Instrumental effect (10 pp.)" ///
				rlikecat "\hspace{1em}Affective effect [-2, 2]" ///
				0.direct#c.msgeffect "\hspace{1em}Anonymous$\times\text{Instrumental belief}$" ///
				0.direct#c.rlikecat "\hspace{1em}Anonymous$\times\text{Affective belief}$" ///
				_cons "Constant" ///
				) ///
		refcat(msgeffect "\multicolumn{7}{l}{\textbf{\textit{Sender's beliefs on the effects of the message:}}} \\ %") ///
		stat(N N_clust r2, fmt(0 0 %4.2f) label("Observations (Responses)" "Senders" "$ R^2$")) ///
		prehead(\begin{table}[h] \centering \begin{adjustbox}{max width=\linewidth} \begin{threeparttable} ///
				\caption{Senders' WTP and beliefs for the Pressure Message: Heterogeneity by gender} ///
				\small{\begin{tabular} {l c c c c c c c c} \toprule ///
				& \multicolumn{2}{c}{Female/other Sender} & \multicolumn{2}{c}{Male Sender} & & & \\ ///
				\cmidrule(lr){2-3} \cmidrule(lr){4-5} ///
				\multicolumn{1}{r}{\textit{Recipient's gender:}} & Fem./other & Male & Fem./other & Male & & & \\ ///
				) ///
		postfoot(\bottomrule \end{tabular}} \label{tab:heterogeneity_gender} ///
			\begin{tablenotes} \footnotesize ///
			\item 	OLS estimates with standard errors clustered by Sender in parentheses. ///
					These regressions replicate the specification in Column 2 of Table \ref{tab:reg} ///
					on the subsample indicated in the column headers. ///
			\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}) ///
		replace
}
