{ // Table A.6b: Senders' WTP and beliefs across experimental conditions: Uncensored WTP
	clear all
	use if complete==1 & attention==1 using "./data/master_long.dta"

	* Combine Strongly (Dis)agree with (Dis)agree due to small counts (pre-registered)
	replace rlikecat=2 if rlikecat==1
	replace rlikecat=6 if rlikecat==7

	replace rlikecat=rlikecat-4 // center at 0
	replace msgeffect=msgeffect/10 // show coefs in units of 10pp.
	
	* To rename in esttab to show difference between columns
	gen di=direct
	gen me=msgeffect
	gen rl=rlikecat
	gen cons=1

	winsor2 wtpsendmax, by(pressure) cuts(10 90) suffix(_w)

	gen wtpsend_uncen = wtpsend
	replace wtpsend_uncen = wtpsendmax_w if wtpsendmax!=.

	eststo clear
	eststo p1: reg   wtpsend_uncen 0.direct msgeffect rlikecat 0.direct#c.rlikecat 0.direct#c.msgeffect if pressure==1, cl(id)
	eststo i1: reg   wtpsend_uncen 0.direct msgeffect rlikecat 0.direct#c.rlikecat 0.direct#c.msgeffect if pressure==0, cl(id)
	eststo d1: reg   wtpsend_uncen 0.di me rl 0.di#c.rl 0.di#c.me 1.pressure 1.pressure#0.direct 1.pressure#c.msgeffect 1.pressure#c.rlikecat 1.pressure#0.direct#c.rlikecat 1.pressure#0.direct#c.msgeffect con, cl(id) nocons

	esttab p* i* d* using "./tables/reg_uncen.tex", ///
		substitute(\_ _) ///
		label nonumber se nostar nogaps nonotes b(%4.2f) /// 
		mlabels("(1)" "(2)" "(1)-(2)", lhs("Dep. Var.: Uncensored WTP to send message (\textdollar)")) ///  "(2)-(4)"
		rename(1.pressure#0.direct 0.direct ///
				1.pressure#c.msgeffect msgeffect ///
				1.pressure#c.rlikecat rlikecat ///
				1.pressure#0.direct#c.rlikecat 0.direct#c.rlikecat ///
				1.pressure#0.direct#c.msgeffect 0.direct#c.msgeffect ///
				1.pressure _cons ///
				) ///
		keep(0.direct msgeffect rlikecat 0.direct#c.msgeffect 0.direct#c.rlikecat _cons) ///
		order(msgeffect rlikecat 0.direct 0.direct#c.msgeffect 0.direct#c.rlikecat _cons) ///
		varlabels(0.direct "Anonymous Message" ///
				msgeffect "\hspace{1em}Instrumental: Persuasive effect of message (10 pp.)" ///
				rlikecat "\hspace{1em}Affective: Recipient's (dis)like of message [-2, 2]" ///
				0.direct#c.msgeffect "\hspace{1em}Anonymous$\times\text{Instrumental belief}$" ///
				0.direct#c.rlikecat "\hspace{1em}Anonymous$\times\text{Affective belief}$" ///
				_cons "Constant" ///
				) ///
		refcat(msgeffect "\multicolumn{4}{l}{\textbf{\textit{Sender's beliefs on the effects of the message:}}} \\ %") ///
		stat(N N_clust r2, fmt(0 0 %4.2f) label("Observations (Responses)" "Senders" "$ R^2$")) ///
		prehead(\begin{table}[h] \centering \begin{threeparttable} ///
				\caption{Senders' WTP and beliefs across experimental conditions: Uncensored WTP} ///
				\begin{tabular} {l c c c} \toprule /// 
				& Pressure Msg. & Info Msg. \\ ///
				\cmidrule(lr){2-2} \cmidrule(lr){3-3}) ///
		postfoot(\bottomrule \end{tabular} \label{tab:reguncen} ///
			\begin{tablenotes} \footnotesize ///
			\item 	OLS estimates with standard errors clustered by Sender in parentheses. ///
					The dependent variable is the \textit{uncensored} willingness-to-pay (WTP) ///
					to send the message assigned to the Sender. ///
					For Senders who gave a WTP at the extremes (-{\textdollar}7 or {\textdollar}7), ///
					the survey asked them to provide their hypothetical WTP beyond these bounds. ///
					For these Senders, I use their hypothetical responses winsorized ///
					at the 10th and 90th percentiles, ///
					which correspond to -{\textdollar}20 and {\textdollar}40 for the Pressure Message ///
					and -{\textdollar}15 to {\textdollar}15 for the Info Message. ///
					See notes from Table \ref{tab:reg}. ///
			\end{tablenotes} \end{threeparttable} \end{table}) ///
		replace
	drop di me rl
}
