{ // Table A.6c: Senders' WTP and beliefs across experimental conditions: Additional sample checks
	* Save id numbers of those who sent required email
	clear all
	use if registered==1 using "./data/master_wide.dta"

	gen byte sent=((optional==0 & send==0 & confirmed==1) | (optional==1 & confirmed==1) | (optional==0 & send==1 & (dm==1|((recipientnum==1&wtpsend1==-7&wtpsendmax1<=-12)|(recipientnum==2&wtpsend2==-7&wtpsendmax2<=-12)|(recipientnum==3&wtpsend3==-7&wtpsendmax3<=-12)))) | (optional==1 & dm==1))

	keep id sent
	isid id
	tempfile sent
	save `sent'

	use "./data/master_long.dta", replace
	merge m:1 id using `sent', assert(3) nogen

	* Combine Strongly (Dis)agree with (Dis)agree due to small counts (pre-registered)
	replace rlikecat=2 if rlikecat==1
	replace rlikecat=6 if rlikecat==7

	replace rlikecat=rlikecat-4 // center at 0
	replace msgeffect=msgeffect/10 // show coefs in units of 10pp.
	
	* To rename in esttab to show difference between columns
	gen di=direct
	gen me=msgeffect
	gen rl=rlikecat
	gen cons=1

	egen wtpsendmax_gt15 = max(!missing(wtpsendmax) & wtpsendmax>15), by(id)

	eststo clear
	
	eststo p0: reg   wtpsend 0.direct msgeffect rlikecat 0.direct#c.rlikecat 0.direct#c.msgeffect if pressure==1 & finished==1 & attention==1, cl(id)
	estadd local finishedall "$\checkmark$"
	
	eststo p1: reg   wtpsend 0.direct msgeffect rlikecat 0.direct#c.rlikecat 0.direct#c.msgeffect if pressure==1 & complete==1 & attention==1 & wtpsendmax_gt15==0, cl(id)
	estadd local drop7 "$\checkmark$"
	
	eststo i0: reg   wtpsend 0.direct msgeffect rlikecat 0.direct#c.rlikecat 0.direct#c.msgeffect if pressure==0 & finished==1 & attention==1, cl(id)
	estadd local finishedall "$\checkmark$"
	
	eststo i1: reg   wtpsend 0.direct msgeffect rlikecat 0.direct#c.rlikecat 0.direct#c.msgeffect if pressure==0 & complete==1 & attention==1 & wtpsendmax_gt15==0, cl(id)
	estadd local drop7 "$\checkmark$"
	
	eststo d0: reg   wtpsend 0.di me rl 0.di#c.rl 0.di#c.me 1.pressure 1.pressure#0.direct 1.pressure#c.msgeffect 1.pressure#c.rlikecat 1.pressure#0.direct#c.rlikecat 1.pressure#0.direct#c.msgeffect cons if finished==1 & attention==1, cl(id) nocons
	estadd local finishedall "$\checkmark$"
	
	eststo d1: reg   wtpsend 0.di me rl 0.di#c.rl 0.di#c.me 1.pressure 1.pressure#0.direct 1.pressure#c.msgeffect 1.pressure#c.rlikecat 1.pressure#0.direct#c.rlikecat 1.pressure#0.direct#c.msgeffect cons if complete==1 & attention==1 & wtpsendmax_gt15==0, cl(id) nocons
	estadd local drop7 "$\checkmark$"

	esttab p* i* d* using "./tables/reg_robust.tex", ///
		substitute(\_ _) ///
		label nonumber se nostar nogaps nonotes b(%4.2f) /// 
		mlabels("(1)" "(2)" "(3)" "(4)" "(1)-(3)" "(2)-(4)", lhs("Dep. Var.: WTP to send message (\textdollar)")) ///  "(2)-(4)"
		rename(1.pressure#0.direct 0.direct ///
				1.pressure#c.msgeffect msgeffect ///
				1.pressure#c.rlikecat rlikecat ///
				1.pressure#0.direct#c.rlikecat 0.direct#c.rlikecat ///
				1.pressure#0.direct#c.msgeffect 0.direct#c.msgeffect ///
				1.pressure _cons ///
				) ///
		keep(0.direct msgeffect rlikecat 0.direct#c.msgeffect 0.direct#c.rlikecat _cons) ///
		order(msgeffect rlikecat 0.direct 0.direct#c.msgeffect 0.direct#c.rlikecat _cons) ///
		varlabels(0.direct "Anonymous Message" ///
				msgeffect "\hspace{1em}Instrumental: Persuasive effect (10 pp.)" ///
				rlikecat "\hspace{1em}Affective: Recipient's (dis)like [-2, 2]" ///
				0.direct#c.msgeffect "\hspace{1em}Anonymous$\times\text{Instrumental belief}$" ///
				0.direct#c.rlikecat "\hspace{1em}Anonymous$\times\text{Affective belief}$" ///
				_cons "Constant" ///
				) ///
		refcat(msgeffect "\multicolumn{7}{l}{\textbf{\textit{Sender's beliefs on the effects of the message:}}} \\ %") ///
		stat(finishedall drop7 N N_clust r2, fmt(0 0 0 0 %4.2f) label("Including Senders who didn't send required email" "Dropping uncensored WTP>15" "Observations (Responses)" "Senders" "$ R^2$")) ///
		prehead(\begin{table}[h] \centering \begin{adjustbox}{max width=\textwidth} \begin{threeparttable} ///
				\caption{Senders' WTP and beliefs across experimental conditions: Additional sample checks} ///
				\begin{tabular} {l c c c c c c} \toprule /// 
				& \multicolumn{2}{c}{Pressure Msg.} & \multicolumn{2}{c}{Info Msg.} \\ ///
				\cmidrule(lr){2-3} \cmidrule(lr){4-5}) ///
		postfoot(\bottomrule \end{tabular} \label{tab:regrobust2} ///
			\begin{tablenotes} \footnotesize ///
			\item 	Coefficient estimates are from linear regressions with standard errors clustered by Sender shown below in parentheses. The dependent variable is the willingness-to-pay (WTP) to email the message. Columns 1 and 3 additionally include Senders who did not send the required emails (Table \ref{tab:attrition}). Columns 2 and 4 drop Senders who state an uncensored WTP greater than \textdollar15. See notes in Table \ref{tab:reg}. ///
			\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}) ///
		replace
}
