{ // Table A.7: Beliefs and willingness for calling friends
	clear all
	use if nophonebank==1 & attention_pass==1 using "./data/supplemental.dta"
	
	* Initialize Mata matrix to store statistics
	mata: tab=J(20,3,"")
	
	qui count
	global denom=`r(N)'
	
	local vallist `" "Very unlikely" "Unlikely" "Somewhat unlikely" "In the middle" "Somewhat likely" "Likely" "Very likely" "I already have" "'
	local row=1
	local l=1
	foreach v in -3 -2 -1 0 1 2 3 9 {
		local lab: word `l' of `vallist'
		qui count if friend_likelihood==`v'
		local pct = string(`r(N)'*100/${denom},"%2.0f")
		mata: tab[`row',1]="\hspace{1em}`lab'"
		mata: tab[`row',2]="`r(N)'"
		mata: tab[`row',3]="`pct'"
		local ++row
		local ++l
	}
	
	local vallist `" "Strongly disagree" "Somewhat disagree" "Neither agree nor disagree" "Somewhat agree" "Strongly agree" "'
	local l=1
	foreach v in -2 -1 0 1 2 {
		local lab: word `l' of `vallist'
		qui count if friend_affective==`v'
		local pct = string(`r(N)'*100/${denom},"%2.0f")
		mata: tab[`row',1]="\hspace{1em}`lab'"
		mata: tab[`row',2]="`r(N)'"
		mata: tab[`row',3]="`pct'"
		local ++row
		local ++l
	}
	
	local vallist `" "Much lower" "Somewhat lower" "About the same" "Somewhat higher" "Much higher" "Not applicable, all my friends are voting for [candidate] already" "'
	local l=1
	foreach v in -2 -1 0 1 2 9 {
		local lab: word `l' of `vallist'
		qui count if friend_instrumental==`v'
		local pct = string(`r(N)'*100/${denom},"%2.0f")
		mata: tab[`row',1]="\hspace{1em}`lab'"
		mata: tab[`row',2]="`r(N)'"
		mata: tab[`row',3]="`pct'"
		local ++row
		local ++l
	}
	
	mata: tab[`row',2]="${denom}"
	mata: tab[`row',3]="100"
	
	* Output Mata matrix to LaTeX
	mmat2tex tab using "./tables/friend.tex", ///
	replace ///
	preheader(\begin{table}[htbp!] ///
			\centering \begin{threeparttable} ///
			\caption{Beliefs and willingness for calling friends} ///
			\begin{tabular} {l c c} \toprule ///
			Response & $ N$ & \% \\ ///
			\hline ///
		) ///
	insertendrow(	///
					1 "\multicolumn{3}{l}{\textit{From now until the election, how likely are you to call your friends about voting in the}} \\ \multicolumn{3}{l}{\textit{election for [candidate]?}} \\ %" ///
					9 "\\ \multicolumn{3}{l}{\textit{My friends would like getting a phone call from me about voting in the election for}} \\ \multicolumn{3}{l}{\textit{[candidate]}} \\ %" ///
					14 "\\ \multicolumn{3}{l}{\textit{If you called your friends instead of strangers, do you think you would have a lower or}} \\ \multicolumn{3}{l}{\textit{higher chance of getting them to vote for [candidate]?}} \\ %" ///
					20 "\hline" ///
				) ///	
	bottom(\bottomrule \end{tabular} \label{tab:friend} ///
	\begin{tablenotes} \footnotesize ///
	\item ///
	\end{tablenotes} \end{threeparttable} \end{table}) 
}
