{ // Table A.8: Difference in likelihood of calling friends vs. volunteering for phone-banking
	clear all
	use if nophonebank==1 & attention_pass==1 using "./data/supplemental.dta"
	
	drop if friend_likelihood==9 // drop already called friends
	global controls 2.party SRS PSA big5* political i.fips
	
	gen friend_diff_likelihood = friend_likelihood - likelihood
	gen friend_diff_affective = friend_affective - affective
	gen byte friend_instru_pos 	= friend_instrumental==1 | friend_instrumental==2
	gen byte friend_instru_neg 	= friend_instrumental<0
	gen byte friend_same_vote 	= friend_instrumental==9
	
	eststo clear
	local r=1
	
	reg friend_diff_likelihood friend_instru_pos friend_same_vote friend_diff_affective, r
	eststo r`r', title("All")
	estadd local controls ""
	local ++r
	
	reg friend_diff_likelihood friend_instru_pos friend_same_vote friend_diff_affective if treated==0, r
	eststo r`r', title("Control")
	estadd local controls ""
	local ++r
	
	reg friend_diff_likelihood friend_instru_pos friend_same_vote friend_diff_affective ${controls}, r
	eststo r`r', title("All")
	estadd local controls "\checkmark"
	local ++r
	
	reg friend_diff_likelihood friend_instru_pos friend_same_vote friend_diff_affective ${controls} if treated==0, r
	eststo r`r', title("Control")
	estadd local controls "\checkmark"
	local ++r
	
	esttab r* using "./tables/friend_reg.tex", ///
		substitute(\_ _) ///
		label nonumber se nostar nogaps nonotes b(%4.2f) /// 
		mlabels(,titles lhs("\multicolumn{1}{r}{\textit{Sample:}}")) eqlabels(none) ///
		keep(friend_instru_pos friend_same_vote friend_diff_affective 2.party SRS PSA big5* political) ///
		order(friend_instru_pos friend_same_vote friend_diff_affective 2.party  SRS PSA big5* political) ///
		varlabels( ///
					friend_instru_pos "\hspace{1em}Higher chance of persuading friends" ///
					friend_same_vote "\hspace{1em}Friends already voting for [candidate]" ///
					friend_diff_affective "\hspace{1em}$ \Delta\text{Affective effect}$" ///
					2.party "Republican" ///
					SRS "Social Responsibility Scale" ///
					PSA "Prosocial Scale" ///
					big5_extra "\hspace{1em}Extraversion" ///
					big5_agree "\hspace{1em}Agreeableness" ///
					big5_consc "\hspace{1em}Conscientiousness" ///
					big5_emostab "\hspace{1em}Emotional Stability" ///
					big5_open "\hspace{1em}Openness to Experience" ///
					political "Political engagement index" ///
				) ///
		refcat( friend_instru_pos "\multicolumn{5}{l}{\textbf{\textit{Beliefs on the relative effects of calling friends vs. strangers}}} \\ %" ///
				big5_extra "\multicolumn{5}{l}{\textit{Big 5 Personality Traits}} \\ %") ///
		stat(controls N r2, fmt(0 0 %03.2f) label("State FE" "$ N$" "$ R^2$")) ///
		prehead(\begin{table}[htbp!] \centering \begin{threeparttable} ///
				\caption{Difference in likelihood of calling friends vs. volunteering for phone-banking} ///
				\begin{tabular} {l c c c c} \toprule ///
				& (1) & (2) & (3) & (4) \\) ///
		postfoot(\bottomrule \end{tabular} \label{tab:friendreg} ///
			\begin{tablenotes} \footnotesize ///
			\item 	This table shows OLS estimates with robust standard errors in parentheses. ///
					The dependent variable is the participants' predicted likelihood of calling friends about voting for their preferred candidate, with responses ranging from -3 (Very unlikely) to 3 (Very likely), minus their predicted likelihood of volunteering for phone-banking. ///
					\say{Higher chance of persuading friends} is an indicator for  participants believing that they will have a higher chance of persuading their friends to vote for their preferred candidate compared to strangers. \say{Friends already voting for [candidate]} is an indicator for participants believing that all their friends are already voting for their preferred candidate. The omitted group for the beliefs on the instrumental effect of calling friends are participants who predict calling friends will have either the same or lower persuasive effect relative to calling strangers. ///
					\say{$ \Delta\text{Affective effect}$} is the difference in the belief on the affective effect for calling friends, minus that for phone-banking strangers. ///
					Columns 2 and 4 contain only participants in the control group. ///
					A small number of participants who state that they have already called their friends are excluded (Table \ref{tab:friend}). ///
			\end{tablenotes} \end{threeparttable} \end{table}) ///
		replace
}
