{ // Table A.9a: Effect of information intervention on beliefs about phone-banking
	clear all
	use if attention_pass==1 & nophonebank==1 using "./data/supplemental.dta"
	
	global controls SRS PSA big5* political i.fips 2.party
	
	eststo clear
	
	eststo r2: reg instrumental_effect treated ${controls}, r
	estadd local controls "\checkmark"
	
	eststo r4: reg affective treated ${controls}, r
	estadd local controls "\checkmark"
	
	* Table A.9a
	esttab r2 r4 using "./tables/first_stage_full.tex", ///
		substitute(\_ _) ///
		label nonumber se nostar nogaps nonotes b(%4.2f) /// 
		mlabels(none) eqlabels(none) ///
		keep(treated 2.party SRS PSA big5* political) ///
		order(treated 2.party SRS PSA big5* political) ///
		varlabels( ///
					treated "Treatment group" ///
					2.party "Republican" ///
					SRS "Social Responsibility Scale" ///
					PSA "Prosocial Scale" ///
					big5_extra "\hspace{1em}Extraversion" ///
					big5_agree "\hspace{1em}Agreeableness" ///
					big5_consc "\hspace{1em}Conscientiousness" ///
					big5_emostab "\hspace{1em}Emotional Stability" ///
					big5_open "\hspace{1em}Openness to Experience" ///
					political "Political engagement index" ///
				) ///
		refcat(big5_extra "\multicolumn{3}{l}{\textit{Big 5 Personality Traits}} \\ %") ///
		stat(controls N r2, fmt(0 0 %03.2f) label("State FE" "$ N$" "$ R^2$")) ///
		prehead(\begin{table}[htbp!] \centering \begin{adjustbox}{max width=\linewidth} \begin{threeparttable} ///
				\caption{Effect of information intervention on beliefs about phone-banking} ///
				\begin{tabular} {l c c} \toprule ///
				& Instrumental beliefs & Affective beliefs \\ ///
				\cmidrule(lr){2-2} \cmidrule(lr){3-3} ///
				& (1) & (2) \\) ///
		postfoot(\bottomrule \end{tabular} \label{tab:firststagefull} ///
			\begin{tablenotes} \footnotesize ///
			\item 	This table shows the results from Table \ref{tab:firststage} with the coefficients on the control variables. ///
					State fixed effects are included (not shown). ///
			\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}) ///
		replace
}
