{ // Table A.9b: Causal effect of instrumental beliefs on volunteering or donating for phone-banking
	clear all
	use if attention_pass==1 & nophonebank==1 using "./data/supplemental.dta"
	
	global controls affective SRS PSA big5* political 2.party i.fips 
	
	replace instrumental_effect=instrumental_effect/10 // show coefs in units of 10pp.
	
	eststo clear
	
	eststo r2: reg likelihood treated ${controls}, r
	estadd local controls "\checkmark"
	
	eststo r4: ivreg2 likelihood (instrumental_effect = treated) ${controls}, r
	estadd local controls "\checkmark"
	
	eststo r6: reg donate treated ${controls}, r
	estadd local controls "\checkmark"
	
	eststo r8: ivreg2 donate (instrumental_effect = treated) ${controls}, r
	estadd local controls "\checkmark"
	
	* Table A.9b
	esttab r2 r4 r6 r8 using "./tables/IV_RF_full.tex", ///
		substitute(\_ _) ///
		label nonumber se nostar nogaps nonotes b(%4.2f) /// 
		mlabels(none) eqlabels(none) ///
		keep(treated instrumental_effect affective 2.party SRS PSA big5* political) ///
		order(treated instrumental_effect affective 2.party SRS PSA big5* political) ///
		varlabels( ///
					treated "Treatment group" ///
					instrumental_effect "\hspace{1em}Instrumental belief (10 pp.)" ///
					affective "\hspace{1em}Affective: Recipient's (dis)like [-2, 2]" ///
					2.party "Republican" ///
					SRS "Social Responsibility Scale" ///
					PSA "Prosocial Scale" ///
					big5_extra "\hspace{1em}Extraversion" ///
					big5_agree "\hspace{1em}Agreeableness" ///
					big5_consc "\hspace{1em}Conscientiousness" ///
					big5_emostab "\hspace{1em}Emotional Stability" ///
					big5_open "\hspace{1em}Openness to Experience" ///
					political "Political engagement index" ///
				) ///
		refcat( instrumental_effect "\multicolumn{5}{l}{\textbf{\textit{Beliefs on the effects of phone-banking}}} \\ %" ///
				big5_extra "\multicolumn{5}{l}{\textit{Big 5 Personality Traits}} \\ %") ///
		stat(controls N r2, fmt(0 0 %03.2f) label("Controls" "$ N$" "$ R^2$")) ///
		prehead(\begin{table}[htbp!] \centering \begin{adjustbox}{max width=\linewidth} \begin{threeparttable} ///
					\caption{Causal effect of instrumental beliefs on volunteering or donating for phone-banking} ///
					\begin{tabular} {l c c c c} \toprule ///
					& \multicolumn{2}{c}{Likelihood of} & \multicolumn{2}{c}{Willingness to} \\ ///
					& \multicolumn{2}{c}{volunteering [-3, 3]} & \multicolumn{2}{c}{donate \textdollar[0,10]} \\ ///
					\cmidrule(lr){2-3} \cmidrule(lr){4-5} ///
					& RF & IV & RF & IV \\ ///
					& (1) & (2) & (3) & (4) \\ ///
				) ///
		postfoot(\bottomrule \end{tabular} \label{tab:rfivfull} ///
			\begin{tablenotes} \footnotesize ///
			\item 	This table shows the results from Table \ref{tab:rfiv} with the coefficients on the control variables. ///
					State fixed effects are included (not shown). ///
			\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}) ///
		replace
}
